
/*******************************************************************
	This namespacing pattern taken from 
	http://addyosmani.com/blog/essential-js-namespacing/

	namespace (our namespace name) and undefined are passed here
	to ensure 1. namespace can be modified locally and isn't
	overwritten outside of our function context
	2. the value of undefined is guaranteed as being truly
	undefined. This is to avoid issues with undefined being
	mutable pre-ES5.
 *******************************************************************/

(function ( DL_Util, undefined ) {

	/*
     * predefined noop so we can make efficient self destroying functions and such
     */
	DL_Util.noop = function (){};

	/****************************************************************

	GAME-SPECIFIC UTILITIES

	****************************************************************/
	
	/*
	 * Generic intersect check with square bounding box.
	 * Takes x, y, width, and height args for objects a and b.
	 * Assumes x: 0, y: 0 is the top left corner
	 * for both objects and the screen
	 */

	DL_Util.boxIntersect = function (aX, aY, aW, aH, bX, bY, bW, bH) {
		return ( aX < bX + bW && aX + aW > bX && aY < bY + bH && aY + aH > bY);
	};

	/*
	 * Intersect check with circular boundaries.
	 * based on observed behavior, it looks like 
	 * this takes radius instead of width. 
	 * May be dependent on anchor point.
	 */
	DL_Util.circleIntersect = function (x1, y1, r1, x2, y2, r2) {
		var xd = x1 - x2;
		var yd = y1 - y2;
		var rt = r2 + r1;
		return (xd * xd + yd * yd <= rt * rt);
	};

	/*
	 * function to deal with number sequences in JSON spritesheets. 
	 * Flash exports png sequences with 4 digit suffixes, 
	 * so use this to determine which one to use when looping 
	 * through spritesheet frames. 
	 * Useful in PIXI.js when loading movieclip textures.
	 */
	DL_Util.numberSuffix = function (i) {
		var num;
		if (i < 9) {
			num = "000" + (i + 1);
		} else if (i < 99) {
			num = "00" + (i + 1);
		} else if (i < 999) {
			num = "0" + (i + 1);
		} else {
			num = i + 1;
		}
		return num;
	};

	/****************************************************************

	PLATFORM / CAPABILITY DETECTION

	****************************************************************/

	/*
	 * User Agent Sniffing method of mobile detection. Gross.
	 * Last Jan 11, 2016
	 * from https://gist.github.com/dalethedeveloper/1503252
	 */
	DL_Util.mobilecheck = function() {
		var check = false;
		( function(a) {
			if (/Mobile|iP(hone|od|ad)|Android|BlackBerry|IEMobile/.test(a)) {
				check = true;
			}
		})(navigator.userAgent);
		return check; 
	};

	/*
	 * Test for touch capabilities.
	 */
	DL_Util.isTouchDevice = function () {
		try{ document.createEvent("TouchEvent"); return true; }
		catch(e){ return false; }
	};

	/****************************************************************

	CON"0.1.0"S

	****************************************************************/

	/*
	 * Converting color types
	 * RGB (e.g. 224, 28, 95) to Hexadecimal (e.g. #e01c5f)
	 * Functions for both directions
	 */
	DL_Util.rgbToHex = function (r, g, b) {
		return "#" + ((1 << 24) + (r << 16) + (g << 8) + b).toString(16).slice(1);
	};

	DL_Util.hexToRgb = function (hex) {
		// Expand shorthand form (e.g. "03F") to full form (e.g. "0033FF")
		var shorthandRegex = /^#?([a-f\d])([a-f\d])([a-f\d])$/i;
		hex = hex.replace(shorthandRegex, function(match, r, g, b) {
			return r + r + g + g + b + b;
		});

		var result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
		return result ? {
			r: parseInt(result[1], 16),
			g: parseInt(result[2], 16),
			b: parseInt(result[3], 16)
		} : null;
	};

	/*
	 * Degrees to Radians
	 */
	DL_Util.d2r = function (d) {
		return d * (Math.PI/180);
	};

	/*
	 * Radians to Degrees
	 */
	DL_Util.r2d = function (r) {
		return r * (180/Math.PI);
	};

	/*
	 * Round input to nearest quarter.
	 * Useful for rounding times from events that cannot 
	 * be guaranteed to fire more frequently than every
	 * 0.25s, e.g. HTML5 video timeupdate.
	 * See https://developer.mozilla.org/en-US/docs/Web/Events/timeupdate
	 * for more details on timeupdate granularity.
	 */
	DL_Util.roundNearQtr = function (number) {
		return (Math.round(number * 4) / 4).toFixed(2);
	};

	/*
	 * Normalizes two vectors, such that |v1|=|v2|=1
	 * Necessary for functions requiring acos
	 */
	DL_Util.normalize = function (x, y) {
		var length = Math.sqrt((x * x) + (y * y));
		return {x: x / length, y: y / length};
	};

	/*
	 * Dot product of two vectors
	 * e.g. multiply two vectors to return a scalar number
	 */
	DL_Util.dot = function (Ax, Ay, Bx, By) {
		return (Ax * Bx) + (Ay * By);
	};

	/*
	 * Returns an angle, in degrees, between two vectors.
	 * Applies arc cos to the dot product of the two vectors.
	 * Range is 0 - 180. Does not give a sign, or full 360 rotation.
	 * Formulas gathered from http://www.euclideanspace.com/maths/algebra/vectors/angleBetween/
	 * because I remember none of this from High School.
	 */
	DL_Util.getSimpleAngle = function (Ax, Ay, Bx, By) {
		var aNorm = DL_Util.normalize(Ax, Ay);
		var bNorm = DL_Util.normalize(Bx, By);
		return Math.acos( (aNorm.x * bNorm.x) + (aNorm.y * bNorm.y) ) * (180/Math.PI);
	};

	/*
	 * Returns the signed angle of vector B relative to vector A, in degrees.
	 */
	DL_Util.getSignedAngle = function (Ax, Ay, Bx, By) {
		var aNorm = DL_Util.normalize(Ax, Ay);
		var bNorm = DL_Util.normalize(Bx, By);
		return (Math.atan2(bNorm.y, bNorm.x) - Math.atan2(aNorm.y, aNorm.x)) * (180/Math.PI);
	};

	/*
	 * Takes an input, converts to string, and pads with a specified character
	 * to return a string of appropriate length.
	 * Mostly useful for adding leading zeroes.
	 * It's _such_ a burden to include this here,
	 * maybe I should use an npm package instead...
	 */
	DL_Util.leftpad = function (input, totalLength, padCharacter) {
		input = String(input);
		var i = -1;
		if (!padCharacter && padCharacter !== 0) {
			padCharacter = ' ';
		}
		totalLength = totalLength - input.length;
		while (++i < totalLength) {
			input = padCharacter + input;
		}
		return input;
	};

	/****************************************************************

	ARRAY AND OBJECT HELPERS

	****************************************************************/

	/*
	 * Get random item from passed array.
	 * Returns the item itself, not the index.
	 */
	DL_Util.randFromArray = function (array) {
		return array[Math.floor(Math.random() * array.length)];
	};

	/*
	 * Get random item from passed object.
	 * Returns the item itself, not the prop name.
	 */
	DL_Util.randFromObject = function (obj) {
		var result;
		var count = 0;
		for (var prop in obj) {
			if (Math.random() < 1/++count) {
				result = prop;
			}
		}
		return result;
	};

	/*
	 * Takes an array of objects, and returns a new object
	 * using a specific property as keys.
	 * Useful when you need to look up the associated object
	 * of a certain property many times.
	 * Data must be consistent. Key values should be present
	 * and unique in all objects to return a complete dict
	 */
	DL_Util.createDictionaryFromArray = function(array, key) {
		var dict = {};
		for (var i = 0; i < array.length; i++) {
			if (array[i].hasOwnProperty(key)) {
				dict[array[i][key]] = array[i];
			}
		}
		return dict;
	};

	/*
	 * Get object with a certain property from an array of objects
	 * Returns the first object that matches the criteria.
	 * Will not return multiple objects.
	 * If no match is found, returns null.
	 * If you will need to look this up multiple times, 
	 * use createDictionary instead.
	 */
	DL_Util.getObjectWithProperty = function (array, key, value) {
		for (var i = 0; i < array.length; i++) {
			if (array[i].hasOwnProperty(key) && array[i].key === value) {
				return array[i];
			}
		}
		return null;
	};

	/*
	 * Get objects with a certain property from an array of objects
	 * Returns an array of objects that match the criteria.
	 * If no match is found, returns empty array.
	 * Good if you have duplicate values
	 */
	DL_Util.getObjectsWithProperty = function (array, key, value) {
		var matches = [];
		for (var i = 0; i < array.length; i++) {
			if (array[i].hasOwnProperty(key) && array[i].key === value) {
				matches.push(array[i]);
			}
		}
		return matches;
	};

	/*
	 * Returns a random integer between min (inclusive) and max (inclusive)
	 * Using Math.round() will give you a non-uniform distribution!
	 */
	DL_Util.getRandomInt = function (min, max) {
		return Math.floor(Math.random() * (max - min + 1)) + min;
	};

	/*
	 * Returns 1 or -1.
	 */
	DL_Util.randPosNeg = function () {
		return Math.random() >= 0.5 ? 1 : -1;
	};

	/*
	 * Basic array randomization function.
	 * Previously modified the Array prototype
	 * but I didn't like doing that... so now
	 * just shuffles the passed array.
	 */
	DL_Util.shuffle = function (array){
		var i = array.length, j, temp;
		if ( i === 0 ) {
			return;
		}
		while ( --i ) {
			j = Math.floor( Math.random() * ( i + 1 ) );
			temp = array[i];
			array[i] = array[j];
			array[j] = temp;
		}
	};

	/*
	 * Checks to see if properties in an object
	 * contain any content. Use to make sure 
	 * object structures that are generated
	 * as empty templates don't pollute your
	 * data set with blank entries.
	 */
	DL_Util.isObjectEmpty = function (obj) {
		for(var prop in obj) {
			if(obj.hasOwnProperty(prop))
			return false;
		}

		return true && JSON.stringify(obj) === JSON.stringify({});
	};

	/****************************************************************

	PARSING

	****************************************************************/

	/*  
	 *  get variable from query string
	 *  so running getQueryVariable('dest') on
	 *  www.mysite.com/default.aspx?dest=aboutus.aspx
	 *  would return
	 *  "aboutus.aspx"
	 */
	DL_Util.getQueryVariable = function (variable) {
		var query = window.location.search.substring(1);
		var vars = query.split('&');
		for (var i = 0; i < vars.length; i++) {
			var pair = vars[i].split('=');
			if (decodeURIComponent(pair[0]) == variable) {
				return decodeURIComponent(pair[1]);
			}
		}
		console.log('Query variable %s not found', variable);
		return null;
	};

	/*
	 *  Get file type from extension. 
	 *  Removes query strings that come 
	 *  after the file request as well. 
	 *  Does NOT deal with invalid inputs 
	 *  at the moment, so should probably 
	 *  validate that input equals output
	 */
	DL_Util.getFileType = function (url) {
		var fileType = url.split('?').shift().split('.').pop().toLowerCase();
		return fileType;
	};

	/****************************************************************

	VALIDATION

	****************************************************************/

	/*
	 * check if value is an integer
	 */
	DL_Util.isInt = function (value) {
		return !isNaN(value) &&
				parseInt(Number(value)) == value &&
				!isNaN(parseInt(value, 10));
	};

	/****************************************************************

	TEXT AND LAYOUT

	****************************************************************/
	/*
	 * takes a jquery selector and inserts a 
	 * non-breaking space character between 
	 * the last two words. Useful for headlines.
	 * Commented out while unused, so as not to 
	 * cause errors due to the jQuery dependency
	 */

	/*
	DL_Util.preventWidows = function (selector) {
		selector.each(function() {
			var wordArray = $(this).text().split(" ");
			if (wordArray.length > 1) {
				wordArray[wordArray.length-2] += "&nbsp;" + wordArray[wordArray.length-1];
				wordArray.pop();
				$(this).html(wordArray.join(" "));
			}
		});    
	}
	*/


	/* 
	 * UNTESTED!!
	 * In theory sets the source of the first img element 
	 * to the one you want to preload. Probably not the best 
	 * way of doing things, might require there to be an img 
	 * element in the dom that is hidden. Test before using 
	 * in production!!
	 */

	/*
	DL_Util.preloadImages = function (array) {
		$(array).each(function(){
			$("<img />")[0].src = this;
		});
	}
	*/

	/*
	 * Better image preloading. 
	 * Feed it an array of image paths, 
	 * and it will return an array of image 
	 * elements ready to be appended to the document.
	 */
    
	DL_Util.preloadImageArray = function(imgPaths) {
		var imageArray = [];
		for (i = 0; i < imgPaths.length; i++) {
			imageArray[i] = new Image();
			imageArray[i].src = imgPaths[i];
		}
		return imageArray;
	};

})(window.DL_Util = window.DL_Util || {});

/****************************************************************

POLYFILLS, NOT NAMESPACED

****************************************************************/

/* 
 * Right now, the polyfills included will always run.
 * May want to comment out those which will not be used
 * in a particular project. Also consider moving these
 * to individual namespaced functions, and using something
 * like yepnope to run them as needed.
 */


/* 
 * polyfill for String.prototype.includes method in ecmascript 6 spec.
 * This is not well supported in all browsers yet.
 */
if (!String.prototype.includes) {
	String.prototype.includes = function() {'use strict';
		return String.prototype.indexOf.apply(this, arguments) !== -1;
	};
}

/* 
 * In case we forget to take out console statements. 
 * IE becomes very unhappy when we forget. 
 * Let's not make IE unhappy
 */
if (typeof(console) === 'undefined') {
	var console = {};
	var consolearray = [];
	console.log = console.groupCollapsed = console.error = console.info = console.debug = console.warn = console.trace = console.dir = console.dirxml = console.group = console.groupEnd = console.time = console.timeEnd = console.assert = console.profile = function(msg) {
		consolearray.push(msg);
	};
}

/*
 * Polyfill for Math.sign method in ecmascript 6 spec.
 * This is not yet supported in IE or Safari
 */
Math.sign = Math.sign || function(x) {
	x = +x; // convert to a number
	if (x === 0 || isNaN(x)) {
		return x;
	}
	return x > 0 ? 1 : -1;
};

/*
 * Polyfill for CustomEvent constructor in IE 11 and under.
 */
try {
	new CustomEvent("customEventPolyfillTest");
} catch(e) {
	var CustomEvent = function(event, params) {
		var evt;
		params = params || {
			bubbles: false,
			cancelable: false,
			detail: undefined
		};

		evt = document.createEvent("CustomEvent");
		evt.initCustomEvent(event, params.bubbles, params.cancelable, params.detail);
		return evt;
	};

	CustomEvent.prototype = window.Event.prototype;
	window.CustomEvent = CustomEvent; // expose definition to window
}

/* Date custom format
 * This code is copyright 2002-2003 by Gavin Kistner, !@phrogz.net
 * It is covered under the license viewable at http://phrogz.net/JS/_ReuseLicense.txt
 *
 * http://stackoverflow.com/questions/4673527/converting-milliseconds-to-a-date-jquery-js
 *
 * Usage example:
 * var date = new Date();
 * var saneDateString = date.customFormat( "#MM#-#DD#-#YYYY# #hh#:#mm#:#ss#" );
 */
Date.prototype.customFormat = function(formatString){
	var YYYY, YY, MMMM, MMM, MM, M, DDDD, DDD, DD, D, hhhh, hhh, hh, h, mm, m, ss, s, ampm, AMPM, dMod, th;

	YY = ((YYYY = this.getFullYear())+"").slice(-2);
	MM = (M = this.getMonth() + 1) < 10 ? ('0' + M) : M;
	MMM = (MMMM = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"][M - 1]).substring(0, 3);
	DD = (D = this.getDate()) < 10 ? ('0' + D) : D;
	DDD = (DDDD = ["Sunday", "Monday","Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"][this.getDay()]).substring(0, 3);
	th = (D >= 10 && D <= 20 ) ? 'th' : ((dMod = D % 10) == 1) ? 'st' : (dMod == 2) ? 'nd' : (dMod == 3) ? 'rd' : 'th';
	formatString = formatString.replace("#YYYY#", YYYY).replace("#YY#", YY).replace("#MMMM#", MMMM).replace("#MMM#", MMM).replace("#MM#", MM).replace("#M#", M).replace("#DDDD#", DDDD).replace("#DDD#", DDD).replace("#DD#", DD).replace("#D#", D).replace("#th#", th);
	h=(hhh = this.getHours());
	if (h === 0) {
		h = 24;
	}
	if (h > 12) {
		h -= 12;
	}
	hh = h < 10 ? ('0' + h) : h;
	hhhh = h < 10 ? ('0' + hhh) : hhh;
	AMPM = (ampm = hhh < 12 ? 'am' : 'pm').toUpperCase();
	mm = (m = this.getMinutes()) < 10 ? ('0' + m) : m;
	ss = (s = this.getSeconds()) < 10 ? ('0' + s) : s;
	return formatString.replace("#hhhh#", hhhh).replace("#hhh#", hhh).replace("#hh#", hh).replace("#h#", h).replace("#mm#", mm).replace("#m#", m).replace("#ss#", ss).replace("#s#", s).replace("#ampm#", ampm).replace("#AMPM#", AMPM);
};
(function()
{
	//Import classes
	var BasePanel = include('springroll.easeljs.BasePanel'),
		Button = include('springroll.easeljs.Button'),
		SoundButton = include('springroll.easeljs.SoundButton'),
		Bitmap = include('createjs.Bitmap'),
		Text = include('createjs.Text'),
		Container = include('createjs.Container');

	/**
	 * Panel contains all of the visual elements for the Game state
	 * @class PrimalScreen.ArcheryGamePanel
	 * @extends springroll.easeljs.BasePanel
	 */
	var ArcheryGamePanel = function()
	{
		BasePanel.call(this);

		this.createScorePanel = this.createScorePanel.bind(this);
	};

	//Super prototype
	var s = BasePanel.prototype;

	//Extend the base panel
	var p = extend(ArcheryGamePanel, BasePanel);

	/**
	 * Setup the state, this happens on each state entering
	 */
	p.setup = function()
	{
		/**
		 * The constructed game stage
		 * @property {createjs.Container} skin
		 */
		this.background = new Bitmap(images.ArcheryGameBackground);
        this.addChildAt(this.background, 0);

        this.skin = new lib.ArcheryGame();
        this.skin.CookieMonsterVictory.framerate = 24;
        this.skin.CookieMonsterVictory.visible = false;
        this.skin.CookieMonsterVictory.stop();
		this.addChild(this.skin);

        this.targetNumberContainer = new Container();
        var targetNumberContainerBackground = new Bitmap(images.TargetNumberContainer);
        this.addChild(this.targetNumberContainer);
        this.targetNumberContainer.addChild(targetNumberContainerBackground);

        this.targetNumberText = new Text("0", "140px Sesame_Teaching_Black", "#81471E");
        // set baseline as per this stackoverflow answer: http://stackoverflow.com/questions/18762795/easeljs-custom-font-lineheight-cross-browser-issues
        this.targetNumberText.textBaseline = "alphabetic";
        this.targetNumberText.x = 130;
        this.targetNumberText.y = 180;
        this.targetNumberText.alpha = 0;
        this.targetNumberText.textAlign = "center";
        this.targetNumberContainer.addChild(this.targetNumberText);

		this.bow = new Container();
		this.addChild(this.bow);

		var bowArt = new Bitmap(images.Bow);
		this.bow.addChild(bowArt);

		this.cookieCounterContainer = new Container();
		var cookieCounterContainerBackground = new Bitmap(images.CookieCounterContainer);
        this.addChild(this.cookieCounterContainer);
        this.cookieCounterContainer.addChild(cookieCounterContainerBackground);

        this.backButton = new SoundButton(images.BackButton);
        this.addChild(this.backButton);

        // create container
		this.scoreScreen = new createjs.Container();

		this.addChild(this.scoreScreen);
	};

	p.createScorePanel = function(score)
	{
		// create background shape
		var scoreBackground = new Bitmap(images.ScoreScreenBackground);
		this.scoreScreen.addChild(scoreBackground);

		this.replayButton = new Button({
			"image": images.ReplayButton,
			"priority": ["disabled", "down", "over", "up"],
			"up": {
				"src": new createjs.Rectangle(0, 0, 230, 230)
			},
			"over": {
				"src": new createjs.Rectangle(0, 230, 230, 230)
			},
			"down": {
				"src": new createjs.Rectangle(0, 460, 230, 230)
			},
			"disabled": {
				"src": new createjs.Rectangle(0, 0, 230, 230)
			}
		});
        this.homeButton = new Button({
			"image": images.HomeButton,
			"priority": ["disabled", "down", "over", "up"],
			"up": {
				"src": new createjs.Rectangle(0, 0, 230, 230)
			},
			"over": {
				"src": new createjs.Rectangle(0, 230, 230, 230)
			},
			"down": {
				"src": new createjs.Rectangle(0, 460, 230, 230)
			},
			"disabled": {
				"src": new createjs.Rectangle(0, 0, 230, 230)
			}
		});

        this.replayButtonHighlight = new Bitmap(images.ButtonHighlight);
        this.replayButtonHighlight.x = 130;
		this.replayButtonHighlight.y = 330;
		this.replayButtonHighlight.alpha = 0;
        this.scoreScreen.addChild(this.replayButtonHighlight);

		// add replay and home buttons
		this.replayButton.x = 150;
		this.replayButton.y = 350;
		this.scoreScreen.addChild(this.replayButton);

		this.homeButtonHighlight = new Bitmap(images.ButtonHighlight);
        this.homeButtonHighlight.x = 580;
		this.homeButtonHighlight.y = 330;
		this.homeButtonHighlight.alpha = 0;
        this.scoreScreen.addChild(this.homeButtonHighlight);
		
		this.homeButton.x = 600;
		this.homeButton.y = 350;
		this.scoreScreen.addChild(this.homeButton);
		
		this.finalScoreDisplayShadow = new createjs.Text(score, "260px Sesame_Teaching_Black", "#0D6694");
		this.finalScoreDisplayShadow.x = 505;
		this.finalScoreDisplayShadow.y = 80;
		this.finalScoreDisplayShadow.textAlign = "center";
		this.scoreScreen.addChild(this.finalScoreDisplayShadow);
		
		this.finalScoreDisplay = new createjs.Text(score, "260px Sesame_Teaching_Black", "#ffffff");
		this.finalScoreDisplay.x = 500;
		this.finalScoreDisplay.y = 80;
		this.finalScoreDisplay.textAlign = "center";
		this.scoreScreen.addChild(this.finalScoreDisplay);
	};

	/**
	 * Un-setup the panel when exiting the state
	 */
	p.teardown = function()
	{
		s.teardown.call(this);
		this.skin = null;
	};

	//Assign to namespace
	namespace('PrimalScreen').ArcheryGamePanel = ArcheryGamePanel;
}());
(function()
{
	//Import classes
	var BasePanel = include('springroll.easeljs.BasePanel'),
		Button = include('springroll.easeljs.Button'),
		SoundButton = include('springroll.easeljs.SoundButton'),
		Bitmap = include('createjs.Bitmap'),
		Text = include('createjs.Text'),
		Container = include('createjs.Container');

	/**
	 * Panel contains all of the visual elements for the Game state
	 * @class PrimalScreen.BreathingExercisePanel
	 * @extends springroll.easeljs.BasePanel
	 */
	var BreathingExercisePanel = function()
	{
		BasePanel.call(this);
	};

	//Super prototype
	var s = BasePanel.prototype;

	//Extend the base panel
	var p = extend(BreathingExercisePanel, BasePanel);

	/**
	 * Setup the state, this happens on each state entering
	 */
	p.setup = function()
	{
		/**
		 * The constructed game stage
		 * @property {createjs.Container} skin
		 */

        this.skin = new lib.BreathingExercise();
        this.skin.mouseEnabled = false;
        this.skin.BreathingMain.CookieBreathing.framerate = 24;
        this.skin.BreathingMain.CookieBreathing.gotoAndStop(app.config.globalState.currentCorrectEmotion);
        this.skin.BreathingMain.GroverInterview.framerate = 24;
        this.skin.BreathingMain.GroverInterview.Blink.framerate = 24;
		this.skin.BreathingMain.GroverInterview.stop();
		this.addChild(this.skin);

		this.backButton = new SoundButton(images.BackButton);
        this.addChild(this.backButton);

        app.states.breathingExercise.onSetup();

        // this.congratsText = new Text("You completed all three competitions!", "80px Sesame_Teaching_Black", "#ffffff");
        // this.addChild(this.congratsText);
	};

	/**
	 * Un-setup the panel when exiting the state
	 */
	p.teardown = function()
	{
		s.teardown.call(this);
		this.skin = null;
	};

	//Assign to namespace
	namespace('PrimalScreen').BreathingExercisePanel = BreathingExercisePanel;
}());
(function()
{
	//Import classes
	var BasePanel = include('springroll.easeljs.BasePanel'),
		Button = include('springroll.easeljs.Button'),
		SoundButton = include('springroll.easeljs.SoundButton'),
		Bitmap = include('createjs.Bitmap'),
		Text = include('createjs.Text'),
		Container = include('createjs.Container');

	/**
	 * Panel contains all of the visual elements for the Game state
	 * @class PrimalScreen.EmotionIdentificationPanel
	 * @extends springroll.easeljs.BasePanel
	 */
	var EmotionIdentificationPanel = function()
	{
		BasePanel.call(this);

		this.createEmotionSelectPanel = this.createEmotionSelectPanel.bind(this);
	};

	//Super prototype
	var s = BasePanel.prototype;

	//Extend the base panel
	var p = extend(EmotionIdentificationPanel, BasePanel);

	/**
	 * Setup the state, this happens on each state entering
	 */
	p.setup = function()
	{
		/**
		 * The constructed game stage
		 * @property {createjs.Container} skin
		 */


        this.skin = new lib.EmotionIdentification();
        this.skin.mouseEnabled = false;
		this.addChild(this.skin);
		this.skin.EmotionsMain.CookieMonsterEmotions.framerate = 24;
		this.skin.EmotionsMain.GroverInterview.framerate = 24;
		this.skin.EmotionsMain.GroverInterview.Blink.framerate = 24;
		this.skin.EmotionsMain.GroverInterview.stop();

		// create container
		this.emotionChoices = new createjs.Container();

		this.emotionChoices.y = 780;
		this.addChild(this.emotionChoices);

		this.backButton = new SoundButton(images.BackButton);
        this.addChild(this.backButton);

        app.states.emotionIdentification.onSetup();

        // this.congratsText = new Text("You completed all three competitions!", "80px Sesame_Teaching_Black", "#ffffff");
        // this.addChild(this.congratsText);
	};

	p.createEmotionSelectPanel = function(emotionSet)
	{
		// create background shape
		var emotionChoiceBackground = new Bitmap(images.emotionSelectBackground);
		emotionChoiceBackground.mouseEnabled = false;
		this.emotionChoices.addChild(emotionChoiceBackground);

		// add highlights for buttons
		this.emotionHighlightOne = new Bitmap(images.buttonHighlight);
		this.emotionHighlightOne.x = 40;
		this.emotionHighlightOne.y = 90;
		this.emotionHighlightOne.alpha = 0;
		this.emotionHighlightOne.mouseEnabled = false;
		this.emotionChoices.addChild(this.emotionHighlightOne);

		this.emotionHighlightTwo = new Bitmap(images.buttonHighlight);
		this.emotionHighlightTwo.x = 340;
		this.emotionHighlightTwo.y = 90;
		this.emotionHighlightTwo.alpha = 0;
		this.emotionHighlightTwo.mouseEnabled = false;
		this.emotionChoices.addChild(this.emotionHighlightTwo);

		this.emotionHighlightThree = new Bitmap(images.buttonHighlight);
		this.emotionHighlightThree.x = 640;
		this.emotionHighlightThree.y = 90;
		this.emotionHighlightThree.alpha = 0;
		this.emotionHighlightThree.mouseEnabled = false;
		this.emotionChoices.addChild(this.emotionHighlightThree);

		// generate buttons from emotion set
		// this.emotionOptionOne = new Button(images[emotionSet[0] + "Button"]);
		this.emotionOptionOne = new Button({
			"image": images[emotionSet[0] + "Button"],
			"priority": ["correct", "disabled", "unused", "down", "over", "up"],
			"up": {
				"src": new createjs.Rectangle(0, 0, 300, 300)
			},
			"over": {
				"src": new createjs.Rectangle(0, 300, 300, 300)
			},
			"down": {
				"src": new createjs.Rectangle(0, 600, 300, 300)
			},
			"unused": {
				"src": new createjs.Rectangle(0, 0, 300, 300)
			},
			"disabled": {
				"src": new createjs.Rectangle(0, 900, 300, 300)				
			},
			"correct": {
				"src": new createjs.Rectangle(0, 600, 300, 300)
			}
		});
        this.emotionOptionOne.emotionName = emotionSet[0];
        this.emotionOptionOne.hitShape = new createjs.Rectangle(0, 0, 300, 300);

        this.emotionOptionTwo = new Button({
			"image": images[emotionSet[1] + "Button"],
			"priority": ["correct", "disabled", "unused", "down", "over", "up"],
			"up": {
				"src": new createjs.Rectangle(0, 0, 300, 300)
			},
			"over": {
				"src": new createjs.Rectangle(0, 300, 300, 300)
			},
			"down": {
				"src": new createjs.Rectangle(0, 600, 300, 300)
			},
			"unused": {
				"src": new createjs.Rectangle(0, 0, 300, 300)
			},
			"disabled": {
				"src": new createjs.Rectangle(0, 900, 300, 300)				
			},
			"correct": {
				"src": new createjs.Rectangle(0, 600, 300, 300)
			}
		});
        this.emotionOptionTwo.emotionName = emotionSet[1];
        this.emotionOptionTwo.hitShape = new createjs.Rectangle(0, 0, 300, 300);

        this.emotionOptionThree = new Button({
			"image": images[emotionSet[2] + "Button"],
			"priority": ["correct", "disabled", "unused", "down", "over", "up"],
			"up": {
				"src": new createjs.Rectangle(0, 0, 300, 300)
			},
			"over": {
				"src": new createjs.Rectangle(0, 300, 300, 300)
			},
			"down": {
				"src": new createjs.Rectangle(0, 600, 300, 300)
			},
			"unused": {
				"src": new createjs.Rectangle(0, 0, 300, 300)
			},
			"disabled": {
				"src": new createjs.Rectangle(0, 900, 300, 300)				
			},
			"correct": {
				"src": new createjs.Rectangle(0, 600, 300, 300)
			}
		});
        this.emotionOptionThree.emotionName = emotionSet[2];
        this.emotionOptionThree.hitShape = new createjs.Rectangle(0, 0, 300, 300);

		// add emotion select buttons
		this.emotionOptionOne.x = 50;
		this.emotionOptionOne.y = 100;
		this.emotionChoices.addChild(this.emotionOptionOne);
		

		this.emotionOptionTwo.x = 350;
		this.emotionOptionTwo.y = 100;
		this.emotionChoices.addChild(this.emotionOptionTwo);
		

		this.emotionOptionThree.x = 650;
		this.emotionOptionThree.y = 100;
		this.emotionChoices.addChild(this.emotionOptionThree);
		
	};

	/**
	 * Un-setup the panel when exiting the state
	 */
	p.teardown = function()
	{
		s.teardown.call(this);
		this.skin = null;
	};

	//Assign to namespace
	namespace('PrimalScreen').EmotionIdentificationPanel = EmotionIdentificationPanel;
}());
(function()
{
	//Import classes
	var BasePanel = include('springroll.easeljs.BasePanel'),
		Button = include('springroll.easeljs.Button'),
		SoundButton = include('springroll.easeljs.SoundButton'),
		Bitmap = include('createjs.Bitmap'),
		Text = include('createjs.Text'),
		Container = include('createjs.Container');

	/**
	 * Panel contains all of the visual elements for the Game state
	 * @class PrimalScreen.FinalePanel
	 * @extends springroll.easeljs.BasePanel
	 */
	var FinalePanel = function()
	{
		BasePanel.call(this);
	};

	//Super prototype
	var s = BasePanel.prototype;

	//Extend the base panel
	var p = extend(FinalePanel, BasePanel);

	/**
	 * Setup the state, this happens on each state entering
	 */
	p.setup = function()
	{
		/**
		 * The constructed game stage
		 * @property {createjs.Container} skin
		 */
		this.background = new Bitmap(images.FinaleBackground);
		this.addChild(this.background);

		this.backButton = new SoundButton(images.BackButton);
        this.addChild(this.backButton);

        this.skin = new lib.Finale();
        this.skin.instance.framerate = 24;
        this.skin.instance.stop();
		this.addChild(this.skin);

        // this.congratsText = new Text("You completed all three competitions!", "80px Sesame_Teaching_Black", "#ffffff");
        // this.addChild(this.congratsText);
	};

	/**
	 * Un-setup the panel when exiting the state
	 */
	p.teardown = function()
	{
		s.teardown.call(this);
		this.skin = null;
	};

	//Assign to namespace
	namespace('PrimalScreen').FinalePanel = FinalePanel;
}());
(function()
{
	//Import classes
	var BasePanel = include('springroll.easeljs.BasePanel'),
		Button = include('springroll.easeljs.Button'),
		Bitmap = include('createjs.Bitmap'),
		Text = include('createjs.Text'),
		Container = include('createjs.Container');

	/**
	 * Panel contains all of the visual elements for the Game state
	 * @class PrimalScreen.GameSelectPanel
	 * @extends springroll.easeljs.BasePanel
	 */
	var GameSelectPanel = function()
	{
		BasePanel.call(this);

		this.addCheckmark = this.addCheckmark.bind(this);
	};

	//Super prototype
	var s = BasePanel.prototype;

	//Extend the base panel
	var p = extend(GameSelectPanel, BasePanel);

	/**
	 * Setup the state, this happens on each state entering
	 */
	p.setup = function()
	{
		this.background = new Bitmap(images.GameSelectBackground);
        this.addChildAt(this.background, 0);

        // add highlights for buttons
		this.ringGameHighlight = new Bitmap(images.SportButtonHighlight);
		this.ringGameHighlight.alpha = 0;
		this.addChild(this.ringGameHighlight);

		this.hurdleGameHighlight = new Bitmap(images.SportButtonHighlight);
		this.hurdleGameHighlight.alpha = 0;
		this.addChild(this.hurdleGameHighlight);

		this.archeryGameHighlight = new Bitmap(images.SportButtonHighlight);
		this.archeryGameHighlight.alpha = 0;
		this.addChild(this.archeryGameHighlight);

		this.ringGameButton = new Button({
			"image": images.RingGameButton,
			"priority": ["disabled", "down", "over", "up"],
			"up": {
				"src": new createjs.Rectangle(26, 27, 293, 449)
			},
			"over": {
				"src": new createjs.Rectangle(26, 507, 293, 449)
			},
			"down": {
				"src": new createjs.Rectangle(26, 985, 293, 449)
			},
			"disabled": {
				"src": new createjs.Rectangle(26, 27, 293, 449)				
			}
		});
		// this.ringGameButton.hitArea = new createjs.Rectangle(26, 27, 293, 449);
		this.ringGameButton.width = 293;
		this.ringGameButton.height = 449;
		this.ringGameButton.enabled = false;
        this.addChild(this.ringGameButton);
        this.ringGameButton.hitShape = new createjs.Rectangle(-5, -5, 303, 459);

        this.hurdleGameButton = new Button({
			"image": images.HurdleGameButton,
			"priority": ["disabled", "down", "over", "up"],
			"up": {
				"src": new createjs.Rectangle(26, 27, 293, 449)
			},
			"over": {
				"src": new createjs.Rectangle(26, 507, 293, 449)
			},
			"down": {
				"src": new createjs.Rectangle(26, 985, 293, 449)
			},
			"disabled": {
				"src": new createjs.Rectangle(26, 27, 293, 449)				
			}
		});
		this.hurdleGameButton.enabled = false;
        this.addChild(this.hurdleGameButton);
        this.hurdleGameButton.hitShape = new createjs.Rectangle(-5, -5, 303, 459);

        this.archeryGameButton = new Button({
			"image": images.ArcheryGameButton,
			"priority": ["disabled", "down", "over", "up"],
			"up": {
				"src": new createjs.Rectangle(26, 27, 293, 449)
			},
			"over": {
				"src": new createjs.Rectangle(26, 507, 293, 449)
			},
			"down": {
				"src": new createjs.Rectangle(26, 985, 293, 449)
			},
			"disabled": {
				"src": new createjs.Rectangle(26, 27, 293, 449)				
			}
		});
		this.archeryGameButton.enabled = false;
        this.addChild(this.archeryGameButton);
        this.archeryGameButton.hitShape = new createjs.Rectangle(-5, -5, 303, 459);

        // add pre-existing checkmarks
		if (app.config.globalState.gamePlayData.ringGame.hasCheckmark === true) {
			this.addCheckmark(this.ringGameButton, false);
		}
		if (app.config.globalState.gamePlayData.archeryGame.hasCheckmark === true) {
			this.addCheckmark(this.archeryGameButton, false);
		}
		if (app.config.globalState.gamePlayData.hurdleGame.hasCheckmark === true) {
			this.addCheckmark(this.hurdleGameButton, false);
		}
	};

	p.addCheckmark = function(element, animate)
	{
		var checkmark = new Bitmap(images.GameButtonCompleteIndicator);
		checkmark.regX = 40;
		checkmark.regY = 40;
		checkmark.x = 250;
		checkmark.y = 375;
		element.addChild(checkmark);

		if (animate) {
			checkmark.scaleX = 0;
			checkmark.scaleY = 0;
			createjs.Tween.get(checkmark).to({scaleX: 1, scaleY: 1}, 800, createjs.Ease.elasticOut);
		}
	};

	/**
	 * Un-setup the panel when exiting the state
	 */
	p.teardown = function()
	{
		s.teardown.call(this);
		this.skin = null;
	};

	//Assign to namespace
	namespace('PrimalScreen').GameSelectPanel = GameSelectPanel;
}());
(function()
{
	//Import classes
	var BasePanel = include('springroll.easeljs.BasePanel'),
		Button = include('springroll.easeljs.Button'),
		SoundButton = include('springroll.easeljs.SoundButton'),
		Bitmap = include('createjs.Bitmap'),
		Text = include('createjs.Text'),
		Container = include('createjs.Container');

	/**
	 * Panel contains all of the visual elements for the Game state
	 * @class PrimalScreen.HurdleGamePanel
	 * @extends springroll.easeljs.BasePanel
	 */
	var HurdleGamePanel = function()
	{
		BasePanel.call(this);

		this.createScorePanel = this.createScorePanel.bind(this);
	};

	//Super prototype
	var s = BasePanel.prototype;

	//Extend the base panel
	var p = extend(HurdleGamePanel, BasePanel);

	/**
	 * Setup the state, this happens on each state entering
	 */
	p.setup = function()
	{
		/**
		 * The constructed game stage
		 * @property {createjs.Container} skin
		 */
		this.background = new Bitmap(images.HurdleGameBackground);
        this.addChildAt(this.background, 0);

        this.background2 = new Bitmap(images.HurdleGameBackground);
        this.addChildAt(this.background2, 0);

        this.finishLineContainer = new Container();
        this.addChild(this.finishLineContainer);

        this.finishLine = new Bitmap(images.FinishLine);
		this.finishLine.x = 1320;
		this.finishLine.y = 0;
		this.finishLineContainer.addChild(this.finishLine);

		this.skin = new lib.HurdleGame();
		this.addChild(this.skin);
		this.skin.CookieMonsterRun.y = app.config.userSettings.hurdleGameOptions.cookieMonsterYPos;
		this.skin.CookieMonsterRun.framerate = 24;
		this.skin.CookieMonsterRun.instance.framerate = 24;
		this.skin.CookieMonsterRun.instance_1.framerate = 24;
		this.skin.CookieMonsterRun.instance_2.framerate = 24;
		this.skin.CookieMonsterRun.instance_3.framerate = 24;
		this.skin.CookieMonsterRun.instance_4.framerate = 24;
		this.skin.CookieMonsterRun.instance_5.framerate = 24;
		this.skin.CookieMonsterRun.instance_6.framerate = 24;
		this.skin.CookieMonsterRun.gotoAndStop(0);
		this.skin.CookieMonsterRun.tickEnabled = false;
		this.skin.CookieMonsterRun.tickChildren = false;

		this.backButton = new SoundButton(images.BackButton);
        this.addChild(this.backButton);

        this.scoreContainer = new Container();
        this.addChild(this.scoreContainer);

        this.scoreContainerBackground = new Bitmap(images.HurdleScoreContainer);
        this.scoreContainer.addChild(this.scoreContainerBackground);

        this.scoreText = new Text("0", "80px Sesame_Teaching_Black", "#000000");
        this.scoreText.x = 115;
        this.scoreText.y = 30;
        this.scoreText.textAlign = "center";
        this.scoreContainer.addChild(this.scoreText);

        // create container
		this.scoreScreen = new createjs.Container();

		this.addChild(this.scoreScreen);

		app.states.hurdleGame.onSetup();
	};

	p.createScorePanel = function(score)
	{
		// create background shape
		var scoreBackground = new Bitmap(images.ScoreScreenBackground);
		this.scoreScreen.addChild(scoreBackground);

		this.replayButton = new Button({
			"image": images.ReplayButton,
			"priority": ["disabled", "down", "over", "up"],
			"up": {
				"src": new createjs.Rectangle(0, 0, 230, 230)
			},
			"over": {
				"src": new createjs.Rectangle(0, 230, 230, 230)
			},
			"down": {
				"src": new createjs.Rectangle(0, 460, 230, 230)
			},
			"disabled": {
				"src": new createjs.Rectangle(0, 0, 230, 230)
			}
		});
        this.homeButton = new Button({
			"image": images.HomeButton,
			"priority": ["disabled", "down", "over", "up"],
			"up": {
				"src": new createjs.Rectangle(0, 0, 230, 230)
			},
			"over": {
				"src": new createjs.Rectangle(0, 230, 230, 230)
			},
			"down": {
				"src": new createjs.Rectangle(0, 460, 230, 230)
			},
			"disabled": {
				"src": new createjs.Rectangle(0, 0, 230, 230)
			}
		});

        this.replayButtonHighlight = new Bitmap(images.ButtonHighlight);
        this.replayButtonHighlight.x = 130;
		this.replayButtonHighlight.y = 330;
		this.replayButtonHighlight.alpha = 0;
        this.scoreScreen.addChild(this.replayButtonHighlight);

		// add replay and home buttons
		this.replayButton.x = 150;
		this.replayButton.y = 350;
		this.scoreScreen.addChild(this.replayButton);

		this.homeButtonHighlight = new Bitmap(images.ButtonHighlight);
        this.homeButtonHighlight.x = 580;
		this.homeButtonHighlight.y = 330;
		this.homeButtonHighlight.alpha = 0;
        this.scoreScreen.addChild(this.homeButtonHighlight);
		
		this.homeButton.x = 600;
		this.homeButton.y = 350;
		this.scoreScreen.addChild(this.homeButton);
		
		this.finalScoreDisplayShadow = new createjs.Text(score, "260px Sesame_Teaching_Black", "#0D6694");
		this.finalScoreDisplayShadow.x = 505;
		this.finalScoreDisplayShadow.y = 80;
		this.finalScoreDisplayShadow.textAlign = "center";
		this.scoreScreen.addChild(this.finalScoreDisplayShadow);
		
		this.finalScoreDisplay = new createjs.Text(score, "260px Sesame_Teaching_Black", "#ffffff");
		this.finalScoreDisplay.x = 500;
		this.finalScoreDisplay.y = 80;
		this.finalScoreDisplay.textAlign = "center";
		this.scoreScreen.addChild(this.finalScoreDisplay);
	};

	/**
	 * Un-setup the panel when exiting the state
	 */
	p.teardown = function()
	{
		s.teardown.call(this);
		this.skin = null;
	};

	//Assign to namespace
	namespace('PrimalScreen').HurdleGamePanel = HurdleGamePanel;
}());
(function()
{
	//Import classes
	var BasePanel = include('springroll.easeljs.BasePanel'),
		Button = include('springroll.easeljs.Button'),
		SoundButton = include('springroll.easeljs.SoundButton'),
		Bitmap = include('createjs.Bitmap'),
		Text = include('createjs.Text'),
		Container = include('createjs.Container');

	/**
	 * Panel contains all of the visual elements for the Game state
	 * @class PrimalScreen.RingGamePanel
	 * @extends springroll.easeljs.BasePanel
	 */
	var RingGamePanel = function()
	{
		BasePanel.call(this);

		this.createScorePanel = this.createScorePanel.bind(this);
	};

	//Super prototype
	var s = BasePanel.prototype;

	//Extend the base panel
	var p = extend(RingGamePanel, BasePanel);

	/**
	 * Setup the state, this happens on each state entering
	 */
	p.setup = function()
	{
		/**
		 * The constructed game stage
		 * @property {createjs.Container} skin
		 */
		this.background = new Bitmap(images.RingGameBackground);
        this.addChildAt(this.background, 0);

		this.skin = new lib.RingGame();
		this.skin.framerate = 24;
		this.skin.BlurVertical.framerate = 24;
		// this.skin.BlurHorizontal.framerate = 24;
		this.addChild(this.skin);

		this.backButton = new SoundButton(images.BackButton);
        this.addChild(this.backButton);

        this.scoreContainer = new Container();
        this.addChild(this.scoreContainer);

        this.scoreContainerBackground = new Bitmap(images.RingsScoreContainer);
        this.scoreContainer.addChild(this.scoreContainerBackground);

        this.scoreText = new Text("0", "80px Sesame_Teaching_Black", "#000000");
        this.scoreText.x = 170;
        this.scoreText.y = 75;
        this.scoreText.textAlign = "center";
        this.scoreContainer.addChild(this.scoreText);

        // create container
		this.scoreScreen = new createjs.Container();

		this.addChild(this.scoreScreen);
	};

	p.createScorePanel = function(score)
	{
		// create background shape
		var scoreBackground = new Bitmap(images.ScoreScreenBackground);
		this.scoreScreen.addChild(scoreBackground);

		this.replayButton = new Button({
			"image": images.ReplayButton,
			"priority": ["disabled", "down", "over", "up"],
			"up": {
				"src": new createjs.Rectangle(0, 0, 230, 230)
			},
			"over": {
				"src": new createjs.Rectangle(0, 230, 230, 230)
			},
			"down": {
				"src": new createjs.Rectangle(0, 460, 230, 230)
			},
			"disabled": {
				"src": new createjs.Rectangle(0, 0, 230, 230)
			}
		});
        this.homeButton = new Button({
			"image": images.HomeButton,
			"priority": ["disabled", "down", "over", "up"],
			"up": {
				"src": new createjs.Rectangle(0, 0, 230, 230)
			},
			"over": {
				"src": new createjs.Rectangle(0, 230, 230, 230)
			},
			"down": {
				"src": new createjs.Rectangle(0, 460, 230, 230)
			},
			"disabled": {
				"src": new createjs.Rectangle(0, 0, 230, 230)
			}
		});

        this.replayButtonHighlight = new Bitmap(images.ButtonHighlight);
        this.replayButtonHighlight.x = 130;
		this.replayButtonHighlight.y = 330;
		this.replayButtonHighlight.alpha = 0;
        this.scoreScreen.addChild(this.replayButtonHighlight);

		// add replay and home buttons
		this.replayButton.x = 150;
		this.replayButton.y = 350;
		this.scoreScreen.addChild(this.replayButton);

		this.homeButtonHighlight = new Bitmap(images.ButtonHighlight);
        this.homeButtonHighlight.x = 580;
		this.homeButtonHighlight.y = 330;
		this.homeButtonHighlight.alpha = 0;
        this.scoreScreen.addChild(this.homeButtonHighlight);
		
		this.homeButton.x = 600;
		this.homeButton.y = 350;
		this.scoreScreen.addChild(this.homeButton);
		
		this.finalScoreDisplayShadow = new createjs.Text(score, "260px Sesame_Teaching_Black", "#0D6694");
		this.finalScoreDisplayShadow.x = 505;
		this.finalScoreDisplayShadow.y = 80;
		this.finalScoreDisplayShadow.textAlign = "center";
		this.scoreScreen.addChild(this.finalScoreDisplayShadow);
		
		this.finalScoreDisplay = new createjs.Text(score, "260px Sesame_Teaching_Black", "#ffffff");
		this.finalScoreDisplay.x = 500;
		this.finalScoreDisplay.y = 80;
		this.finalScoreDisplay.textAlign = "center";
		this.scoreScreen.addChild(this.finalScoreDisplay);
	};

	/**
	 * Un-setup the panel when exiting the state
	 */
	p.teardown = function()
	{
		s.teardown.call(this);
		this.skin = null;
	};

	//Assign to namespace
	namespace('PrimalScreen').RingGamePanel = RingGamePanel;
}());
(function()
{
    //Import classes
    var BasePanel = include('springroll.easeljs.BasePanel'),
        Bitmap = include('createjs.Bitmap'),
        SoundButton = include('springroll.easeljs.SoundButton');

    /**
     * Panel contains all of the visual elements for the title state
     * @class PrimalScreen.TitlePanel
     * @extends springroll.easeljs.BasePanel
     */
    var TitlePanel = function()
    {
        BasePanel.call(this);
    };

    //Super prototype
    var s = BasePanel.prototype;

    //Extend the base panel
    var p = extend(TitlePanel, BasePanel);

    /**
     * Setup the state, this happens on each state entering
     */
    p.setup = function()
    {
        this.background = new Bitmap(images.TitleBackground);
        this.playButton = new SoundButton(images.PlayButton);
        this.addChild(this.background);
        this.addChild(this.playButton);
    };

    /**
     * Un-setup the panel when exiting the state
     */
    p.teardown = function()
    {
        s.teardown.call(this);
        this.background = null;
        this.playButton = null;
    };

    //Assign to namespace
    namespace('PrimalScreen').TitlePanel = TitlePanel;
}());
(function()
{
	//Import classes
	var BaseState = include('springroll.easeljs.BaseState'),
	Ticker = include('createjs.Ticker'),
	Sound = include('springroll.Sound'),
	Bitmap = include('createjs.Bitmap'),
	Delay = include('springroll.DelayedCall'),
	ArcheryGamePanel = include('PrimalScreen.ArcheryGamePanel');

	/**
	 * The logic for the game state
	 * @class PrimalScreen.ArcheryGameState
	 * @extends springroll.easeljs.BaseState
	 */
	var ArcheryGameState = function(options)
	{
		BaseState.call(this, new ArcheryGamePanel(), options);

		// binding functions
		this.onTick = this.onTick.bind(this);
		this.onBack = this.onBack.bind(this);
		this.onReplay = this.onReplay.bind(this);
		this.onHome = this.onHome.bind(this);
		this.onGameEnd = this.onGameEnd.bind(this);
		this.onStopGameplay = this.onStopGameplay.bind(this);
		this.introInstructions = this.introInstructions.bind(this);
		this.abridgedIntroInstructions = this.abridgedIntroInstructions.bind(this);
		this.introTargetChipNumber = this.introTargetChipNumber.bind(this);
		this.introTargetCookieNumber = this.introTargetCookieNumber.bind(this);
		this.introExit = this.introExit.bind(this);
		this.onInstructionsComplete = this.onInstructionsComplete.bind(this);
		this.getValidNumberForRound = this.getValidNumberForRound.bind(this);
		this.populateTargets = this.populateTargets.bind(this);
		this.addTarget = this.addTarget.bind(this);
		this.countTotalCorrect = this.countTotalCorrect.bind(this);
		this.addIntroTarget = this.addIntroTarget.bind(this);
		this.onTargetCompleteIntro = this.onTargetCompleteIntro.bind(this);
		this.addCookieToCount = this.addCookieToCount.bind(this);
		this.onTargetFinishMotion = this.onTargetFinishMotion.bind(this);
		this.stopSpawningTargets = this.stopSpawningTargets.bind(this);
		this.onChangeBowPosition = this.onChangeBowPosition.bind(this);
		this.addArrow = this.addArrow.bind(this);
		this.onFireArrow = this.onFireArrow.bind(this);
		this.onArrowHit = this.onArrowHit.bind(this);
		this.onCorrectAnswer = this.onCorrectAnswer.bind(this);
		this.onIncorrectAnswer = this.onIncorrectAnswer.bind(this);
		this.onArrowBounceComplete = this.onArrowBounceComplete.bind(this);
		this.onWrapUpComplete = this.onWrapUpComplete.bind(this);
		this.fireCompleteScreenButtonPrompt = this.fireCompleteScreenButtonPrompt.bind(this);
		this.fireGameplayPrompt = this.fireGameplayPrompt.bind(this);
		this.onCharacterReact = this.onCharacterReact.bind(this);

		this.onInactivityTimeout = this.onInactivityTimeout.bind(this);
		this.continueInactivityTimeout = this.continueInactivityTimeout.bind(this);
		this.onResetInactivityTimeout = this.onResetInactivityTimeout.bind(this);

		this.inactivityTimeout = null;
		this.wrapUpTimeout = null;

		// tracking vars
		this.targetHitCount = 0; // number of targets we have hit so far
		this.shotsFired = 0; // total number of arrows fired
		this.actionsSinceLastReaction = 0;
		this.cookieCounters = []; // array of bitmaps representing cookie count
		this.currentWrongAnswerCount = 0; // number of consecutive misses
		this.targetNumberToHit = 0; // number of chocolate chips we are looking for
		this.currentRound = 0;
		this.highlightsActive = false;
		this.targetPool = [];
		this.activeTargets = [];
		this.targetsToHit = []; // list of targets to be destroyed when arrow flight is complete
		this.arrowPool = [];
		this.activeArrows = [];
		this.ricochetingArrows = [];
		this.introSequence = null; // intro delay
		this.introSequenceTween = null; // intro tween
		this.introComplete = false;
		this.referenceTarget = null;
		this.widthToCross = 1320; // reset later
		this.targetX = 0; // x position where arrow should fire
		this.adjustedTimeToCrossScreen = 18000;
		this.spawnWaitTime = 0;
		this.enableSpawning = false;
		this.completeScreenVisible = false;
		this.arrowFireDebounce = 0;

		this.playingIncorrectFeedback = false;

		this.totalTargetsSpawned = 0;

		this.spawnTimeout = null;
		this.spawnEndTimeout = null;
		this.gameTimeout = null;
	};

	//Extend the base state
	var p = extend(ArcheryGameState, BaseState);

	/**
	 * After assets are loaded and state is fully entered
	 * @method  enterDone
	 */
	p.enterDone = function()
	{
		//config vars
		this.targetSpacing = app.config.userSettings.archeryGameOptions.targetSpacing;
		this.timeToCrossScreen = app.config.userSettings.archeryGameOptions.timeToCrossScreen;
		this.minTimeToCrossScreen = app.config.userSettings.archeryGameOptions.minTimeToCrossScreen;
		this.maxTimeToCrossScreen = app.config.userSettings.archeryGameOptions.maxTimeToCrossScreen;
		this.averageTimeToCrossScreen = (this.minTimeToCrossScreen + this.maxTimeToCrossScreen) / 2;
		this.timeAdjustmentIncrement = app.config.userSettings.archeryGameOptions.timeAdjustmentIncrement;
		this.arrowFlightTime = app.config.userSettings.archeryGameOptions.arrowFlightTime;

		this.panel.skin.tickEnabled = false; // We cannot change the sorting order of children without doing this
		this.completeScreenVisible = false;
		this.playingIncorrectFeedback = false;

		this.panel.backButton.addEventListener("click", this.onBack);
		this.panel.backButton.alpha = 1;

		this.currentRound = app.config.globalState.gamePlayData.archeryGame.totalPlays;
		this.targetNumberToHit = this.getValidNumberForRound(this.currentRound);

		
		this.panel.targetNumberText.text = this.targetNumberToHit.toString();
		this.panel.targetNumberText.alpha = 1;

		// this.onInstructionsComplete();

		this.introInstructions();

		Ticker.addEventListener('tick', this.onTick);
	};

	/**
	 * Update loop for game logic, which fires every tick.
	 * @method  onTick
	 */
	p.onTick = function()
	{	
		// check for spawn
		if (this.enableSpawning === true) {
			if ((1320 + this.targetOffset) - this.activeTargets[this.activeTargets.length - 1].x > this.targetSpacing + this.referenceTarget.width) {
				this.addTarget(1320 + this.targetOffset);
			}
		}
		this.arrowFireDebounce += 1;
	};

	/**
	 * Get number of chocolate chips that is within the acceptable range for the current round.
	 * @method  getValidNumberForRound
	 */
	p.getValidNumberForRound = function(round)
	{
		if (round === 0) {
			// range 1 - 4
			return Math.ceil(Math.random() * 3);
		} else if (round === 1) {
			// range 5 - 7
			return Math.ceil(Math.random() * 2) + 3;
		} else {
			// range 1 - 7
			return Math.ceil(Math.random() * 5);
		}
	};

	p.introInstructions = function()
	{
		this.introTarget = new lib.CookieTarget();
		this.introTarget.framerate = 24;
		this.panel.skin.addChild(this.introTarget);

		this.introTarget.x = 700;
		this.introTarget.y = 450;
		this.introTarget.state = "intact";
		this.introTarget.number = this.targetNumberToHit;
		this.introTarget.gotoAndStop("Count" + this.targetNumberToHit);

		this.voPlayer.play("CG_57", this.introTargetChipNumber);

	};

	p.introTargetChipNumber = function()
	{
		var introVo = [];
		introVo.push("CG_58");
		introVo.push("CG_" + (app.config.userSettings.numberVoOffsets.chips + this.targetNumberToHit));
		introVo.push(0.3);
		introVo.push(app.config.globalState.inputPrompts.grover);
		introVo.push("CG_59");
		introVo.push("CG_" + (app.config.userSettings.numberVoOffsets.chips + this.targetNumberToHit));
		this.voPlayer.play(introVo, this.introTargetCookieNumber);

		this.introSequenceTween = createjs.Tween.get(this.panel.targetNumberContainer)
			.to({y: 350 * app.scaling.scale}, 500, createjs.Ease.sineOut)
			.to({y: 400 * app.scaling.scale}, 500, createjs.Ease.sineIn)
			.to({y: 350 * app.scaling.scale}, 500, createjs.Ease.sineOut)
			.to({y: 400 * app.scaling.scale}, 500, createjs.Ease.sineIn)
			.to({y: 350 * app.scaling.scale}, 500, createjs.Ease.sineOut)
			.to({y: 400 * app.scaling.scale}, 500, createjs.Ease.sineIn);
	};

	p.introTargetCookieNumber = function()
	{
		var introVo = [];
		// count up
		for (var i = 0; i < this.targetNumberToHit; i++) {
			introVo.push("CG_" + (app.config.userSettings.numberVoOffsets.final + i + 1));
		}
		this.voPlayer.play(introVo, this.introExit);

		this.introTarget.play();
	};

	p.introExit = function()
	{
		this.introSequenceTween = createjs.Tween.get(this.introTarget).to({x: -100}, 1000, createjs.Ease.backIn).call(this.onInstructionsComplete);
	};

	p.onInstructionsComplete = function()
	{
		if (this.introTarget) {
			this.panel.skin.removeChild(this.introTarget);
		}
		this.populateTargets();
		
	};

	p.abridgedIntroInstructions = function()
	{
		var introVo = [];
		introVo.push("CG_58");
		introVo.push("CG_" + (app.config.userSettings.numberVoOffsets.chips + this.targetNumberToHit));
		this.voPlayer.play(introVo);

		this.introSequenceTween = createjs.Tween.get(this.panel.targetNumberContainer)
			.to({y: 350 * app.scaling.scale}, 500, createjs.Ease.sineOut)
			.to({y: 400 * app.scaling.scale}, 500, createjs.Ease.sineIn)
			.to({y: 350 * app.scaling.scale}, 500, createjs.Ease.sineOut)
			.to({y: 400 * app.scaling.scale}, 500, createjs.Ease.sineIn)
			.to({y: 350 * app.scaling.scale}, 500, createjs.Ease.sineOut)
			.to({y: 400 * app.scaling.scale}, 500, createjs.Ease.sineIn);

		this.populateTargets();
	};

	/**
	 * Populate the game area with the first targets, and start the spawn loop
	 * @method  populateTargets
	 */
	p.populateTargets = function()
	{

		// set variables for target sizes and spacing
		var tempTarget = new lib.CookieTarget();
		this.referenceTarget = tempTarget.nominalBounds;
		this.widthToCross = 1320 + this.referenceTarget.width;
		this.targetOffset = this.referenceTarget.width / 2;
		var xOffset = 0;
		var iterations = 0;

		while (xOffset < 1320) {
			xOffset = (iterations * this.targetSpacing) + (iterations * this.referenceTarget.width);
			if (iterations === 0) {
				this.addIntroTarget(xOffset, true); // force the first target to be incorrect
			} else {
				this.addIntroTarget(xOffset, false);
			}
			iterations += 1;
		}
	};

	p.addIntroTarget = function(x, forceIncorrect)
	{
		// cut down, special version of target spawns
		this.totalTargetsSpawned += 1;
		this.activeTargets.push(new lib.CookieTarget());
		var index = this.activeTargets.length - 1;
		this.panel.skin.addChild(this.activeTargets[index]);

		var cookieNumber = -1;
		if (forceIncorrect) {
			while (cookieNumber === -1 || cookieNumber === this.targetNumberToHit) {
				cookieNumber = this.getValidNumberForRound(this.currentRound);
			}
		} else {
			cookieNumber = this.totalTargetsSpawned % 3 === 0 ? this.targetNumberToHit : this.getValidNumberForRound(this.currentRound);
		}
		var cookieNumberIndex = ((cookieNumber - 1) * 3) + Math.floor(Math.random() * 3);

		this.activeTargets[index].x = x + 1320;
		this.activeTargets[index].y = 450;
		this.activeTargets[index].state = "intact";
		this.activeTargets[index].number = cookieNumber;
		this.activeTargets[index].gotoAndStop(cookieNumberIndex);

		this.activeTargets[index].CookieTargetHighlight.gotoAndStop("Off");

		var xTo = 0 - this.targetOffset;
		var duration = this.adjustedTimeToCrossScreen * ((x + this.targetOffset) / this.widthToCross);

		createjs.Tween.get(this.activeTargets[index]).to({x: x}, 1000, createjs.Ease.sineOut).call(
			this.onTargetCompleteIntro, 
			[this.activeTargets[index],
			xTo,
			duration], 
			this);
	};

	p.onTargetCompleteIntro = function(target, xTo, duration)
	{
		createjs.Tween.get(target).to({x: xTo}, duration).call(this.onTargetFinishMotion);

		if (!this.introComplete) {
			this.introComplete = true;

			this.enableSpawning = true;

			// adding arrows and interaction
			this.panel.stage.addEventListener("stagemousemove", this.onChangeBowPosition); // no longer changing bow pos
			this.panel.addEventListener("pressup", this.onFireArrow);

			this.addArrow();
			// adding game timeouts
			
			var timeToEndSpawning = app.config.userSettings.gameDurations.archery - this.minTimeToCrossScreen;
			this.spawnEndTimeout = new Delay(this.stopSpawningTargets, timeToEndSpawning);
			this.gameTimeout = new Delay(this.onGameEnd, app.config.userSettings.gameDurations.archery);

			app.sound.play("music_gameplayloop.L");

			// start the inactivity timeout for the first time
			app.config.globalState.firstInactivityTimeoutTime = 0;
			this.onResetInactivityTimeout();
		}
	};

	p.addTarget = function(x)
	{
		this.totalTargetsSpawned += 1;

		if (this.targetPool.length > 0) {
			this.activeTargets.push(this.targetPool.shift());
		} else {
			this.activeTargets.push(new lib.CookieTarget());
		}
		var index = this.activeTargets.length - 1;
		this.panel.skin.addChild(this.activeTargets[index]);

		var forceIncorrect = false;
		if (this.countTotalCorrect() >= 20) {
			// don't let us get more than 20
			forceIncorrect = true;
		}

		var cookieNumber = -1;
		if (forceIncorrect === true) {
			while (cookieNumber === -1 || cookieNumber === this.targetNumberToHit) {
				cookieNumber = this.getValidNumberForRound(this.currentRound);
			}
		} else {
			cookieNumber = this.totalTargetsSpawned % 3 === 0 ? this.targetNumberToHit : this.getValidNumberForRound(this.currentRound);
		}

		var cookieNumberIndex = ((cookieNumber - 1) * 3) + Math.floor(Math.random() * 3);

		this.activeTargets[index].x = x;
		this.activeTargets[index].y = 450;
		this.activeTargets[index].state = "intact";
		this.activeTargets[index].number = cookieNumber;
		this.activeTargets[index].gotoAndStop(cookieNumberIndex);

		if (this.highlightsActive && cookieNumber === this.targetNumberToHit) {
			this.activeTargets[index].CookieTargetHighlight.gotoAndPlay("Pulse");
		} else {
			this.activeTargets[index].CookieTargetHighlight.gotoAndStop("Off");
		}
		
		var xTo = 0 - this.targetOffset;
		var duration = this.adjustedTimeToCrossScreen * ((x + this.targetOffset) / this.widthToCross);

		createjs.Tween.get(this.activeTargets[index]).to({x: xTo}, duration).call(this.onTargetFinishMotion);

		/*if (this.activeArrows.length) {
			this.panel.skin.setChildIndex(this.activeArrows[this.activeArrows.length - 1], this.panel.skin.children.length - 1);
		}*/
		
	};

	p.countTotalCorrect = function() {
		var total = 0;
		total += this.targetHitCount;
		for (var i = 0; i < this.activeTargets.length; i++) {
			if (this.activeTargets[i].number === this.targetNumberToHit && this.activeTargets[i].state === 'intact') {
				// correct intact target - add to total
				total += 1;
			}
		}
		return total;
	};

	p.addCookieToCount = function()
	{
		if (this.cookieCounters.length >= 20) {
			return;
		}

		var newCounter = new Bitmap(images.CookieCounter);
		if (this.cookieCounters.length < 10) {
			newCounter.x = (this.cookieCounters.length % 10) * 40 + 30;
			newCounter.y = 10;
		} else {
			newCounter.x = (this.cookieCounters.length % 10) * 40 + 30;
			newCounter.y = 50;
		}
		this.cookieCounters.push(newCounter);
        this.panel.cookieCounterContainer.addChild(newCounter);
	};

	p.onTargetFinishMotion = function()
	{
		this.targetPool.push(this.activeTargets.shift());
		this.panel.skin.removeChild(this.targetPool[this.targetPool.length - 1]);
	};

	p.stopSpawningTargets = function()
	{
		this.enableSpawning = false;
	};

	p.onChangeBowPosition = function(event)
	{
		this.targetX = (event.stageX - this.panel.skin.x) / app.scaling.scale;

		// rotate arrow to follow target
		// first vector is the target, second is current arrow position
		// 450 - 300 is the arrow y position - the target y position
		// This is to account for the reversed y values compared to typical cartesian coordinates

		var rot = DL_Util.getSignedAngle(this.targetX - 1020, (450 - 300), 0, (450 - 300)); // arrow points where mouse points
		// var rot = DL_Util.getSignedAngle(700 - this.targetX, (450 - 300), 0, (450 - 300)); // mouse steers back of arrow
		if (rot >= 0) {
			rot = 0;
		}
		this.activeArrows[this.activeArrows.length - 1].rotation = rot;
	};

	p.addArrow = function()
	{
		if (this.arrowPool.length > 0) {
			this.activeArrows.push(this.arrowPool.shift());
		} else {
			this.activeArrows.push(new Bitmap(images.Arrow));
		}

		var index = this.activeArrows.length - 1;
		this.panel.bow.addChild(this.activeArrows[index]);

		// set starting position
		this.activeArrows[index].x = 420;
		this.activeArrows[index].y = 850; // off screen
		this.activeArrows[index].regX = 25;
		this.activeArrows[index].regY = 25;
		this.activeArrows[index].scaleX = 1;
		this.activeArrows[index].scaleY = 1;
		this.activeArrows[index].alpha = 1;
		var rot = DL_Util.getSignedAngle(this.targetX - 1020, (450 - 300), 0, (450 - 300)); // arrow points where mouse points
		// var rot = DL_Util.getSignedAngle(700 - this.targetX, (450 - 300), 0, (450 - 300)); // mouse steers back of arrow
		if (rot >= 0) {
			rot = 0;
		}
		this.activeArrows[index].rotation = rot;

		createjs.Tween.get(this.activeArrows[index]).to({x: 475, y: 405}, 500, createjs.Ease.backOut);
	};

	p.onFireArrow = function(event)
	{
		if (app.hasTouch) {
			if (event.nativeEvent.touches.length > 0 || this.arrowFireDebounce < 8) {
				// this was not the only finger we lifted
				return;
			}
		}
		
		this.arrowFireDebounce = 0;
		app.sound.play("archery");
		this.onCharacterReact();
		this.shotsFired += 1;
		this.onResetInactivityTimeout();

		this.targetX = (event.stageX - this.panel.skin.x) / app.scaling.scale; // arrow follow mouse
		/*var pointerX = event.stageX / app.scaling.scale; // mouse steers back of arrow
		this.targetX = 1320 - pointerX;*/

		var index = this.activeArrows.length - 1;
		createjs.Tween.removeTweens(this.activeArrows[index]);

		var tempRotation = this.activeArrows[index].rotation;
		this.activeArrows[index].rotation = 0;

		// move arrow from bow to main panel
		this.panel.bow.removeChild(this.activeArrows[index]);
		this.panel.skin.addChild(this.activeArrows[index]);
		// convert local bow space to world space position

		// pretty close, not 100%
		this.activeArrows[index].x = 1170 + this.panel.skin.x;
		this.activeArrows[index].y = 445 + this.panel.skin.y;
		this.activeArrows[index].rotation = tempRotation;

		if (this.targetX > 700) {
			this.activeArrows[index].scaleX = -1;
		}

		// assume miss until proven otherwise
		var arrowLeadAmount = this.widthToCross * (this.arrowFlightTime / this.adjustedTimeToCrossScreen);
		var xTo = this.targetX - arrowLeadAmount;
		var yTo = 300;
		var scaleTo = 0;

		var hit = false;
		var correct = false;

		var hitObjects = this.panel.skin.getObjectsUnderPoint(this.targetX, 300, 1);

		for (var i = 0; i < hitObjects.length; i++) {
			// if we hit an active target
			// and that target has not already been broken
			// shoot an arrow that will hit it
			if (this.activeTargets.indexOf(hitObjects[i].parent) !== -1 && hitObjects[i].parent.state === 'intact') {
				hit = true; // we hit an actual valid target

				// if we hit a correct answer
				// and it is not already on the list to be broken
				// i.e. will still be there when the arrow arrives
				// add it to the hit list

				if (this.targetNumberToHit === hitObjects[i].parent.number && this.targetsToHit.indexOf(hitObjects[i].parent) === -1) {
					correct = true; // this target is one we were trying to hit

					this.targetsToHit.push(hitObjects[i].parent);
					// yTo = 300;
					if (this.targetX > 700) {
						scaleTo = -0.1;
					} else {
						scaleTo = 0.1;
					}

				} else if (this.targetNumberToHit === hitObjects[i].parent.number && this.targetsToHit.indexOf(hitObjects[i].parent) !== -1) {
					// correct answer will already be broken by the time we get there
					correct = false;
				} else {
					// else we hit a wrong answer
					correct = false;

					this.targetsToHit.push(hitObjects[i].parent);

					if (this.targetX > 700) {
						scaleTo = -0.1;
					} else {
						scaleTo = 0.1;
					}
				}
				
				break;
			}
		}

		// if (hit && !correct) {
		// 	app.sound.play("miss");
		// }

		createjs.Tween.get(this.activeArrows[index]).to({y: yTo, x: xTo, scaleX: scaleTo, scaleY: Math.abs(scaleTo / 2)}, this.arrowFlightTime, createjs.Ease.sineOut).call(this.onArrowHit);
		this.addArrow();
	};

	p.onArrowHit = function(event)
	{

		// make sure this target wasn't broken already by a previous arrow
		if (this.targetsToHit.length > 0) {
			if (this.targetsToHit[0].state === 'intact' && this.targetNumberToHit === this.targetsToHit[0].number) {
				this.onCorrectAnswer();
			} else {
				// wrong because we hit an incorrect cookie
				// app.sound.play("miss");
				this.onIncorrectAnswer(true);
			}

			this.targetsToHit.shift();

		} else {
			// wrong because we missed a cookie entirely
			// should we make this count as a wrong answer for feedback purposes?

			this.onIncorrectAnswer(false);
		}

		var xTo = 0 - this.targetOffset;

		// adjust movement speed for all targets
		for (var i = 0; i < this.activeTargets.length; i++) {
			createjs.Tween.removeTweens(this.activeTargets[i]);

			var duration = this.adjustedTimeToCrossScreen * ((this.activeTargets[i].x + this.targetOffset) / this.widthToCross);

			createjs.Tween.get(this.activeTargets[i]).to({x: xTo}, duration).call(this.onTargetFinishMotion);
		}
		
	};

	p.onCorrectAnswer = function()
	{
		this.targetsToHit[0].gotoAndPlay('Break');
		this.targetHitCount += 1;
		this.addCookieToCount();
		this.currentWrongAnswerCount = 0;
		if (this.playingIncorrectFeedback) {
			this.playingIncorrectFeedback = false;
			this.onCharacterReact(true);
		}
		app.sound.play("bellyes");

		// go faster
		var adjustmentMultiplier = Math.pow(this.adjustedTimeToCrossScreen / this.averageTimeToCrossScreen, 2);
		this.adjustedTimeToCrossScreen = Math.max(this.adjustedTimeToCrossScreen - (this.timeAdjustmentIncrement * adjustmentMultiplier), this.minTimeToCrossScreen);

		this.highlightsActive = false;
		for (var i = 0; i < this.activeTargets.length; i++) {
			this.activeTargets[i].CookieTargetHighlight.gotoAndStop("Off");
		}

		// move currently active arrow 
		this.arrowPool.push(this.activeArrows.shift());
		this.panel.skin.removeChild(this.arrowPool[this.arrowPool.length - 1]);
	};

	p.onIncorrectAnswer = function(giveFeedback)
	{
		// slow down
		var adjustmentMultiplier = Math.pow(this.adjustedTimeToCrossScreen / this.averageTimeToCrossScreen, 2);
		this.adjustedTimeToCrossScreen = Math.min(this.adjustedTimeToCrossScreen + (this.timeAdjustmentIncrement * adjustmentMultiplier), this.maxTimeToCrossScreen);
		app.sound.play("hurdlebounce");

		// if player missed a cookie entirely, don't count it as wrong
		if (!giveFeedback) {
			this.arrowPool.push(this.activeArrows.shift());
			this.panel.skin.removeChild(this.arrowPool[this.arrowPool.length - 1]);
			return;
		}

		this.currentWrongAnswerCount += 1;

		var feedbackVo = [];
		
		if (this.currentWrongAnswerCount === 1) {
			// play first wrong vo
			feedbackVo.push("CG_64");

		} else if (this.currentWrongAnswerCount === 2) {
			// play second wrong vo
			feedbackVo.push("CG_65");
			feedbackVo.push("CG_" + (app.config.userSettings.numberVoOffsets.chips + this.targetNumberToHit));
		} else {
			// play wrong vo and highlight
			feedbackVo.push(app.config.globalState.inputPrompts.cookie);
			feedbackVo.push("CG_67");

			if (!this.highlightsActive) {
				this.highlightsActive = true;
				for (var i = 0; i < this.activeTargets.length; i++) {
					if (this.activeTargets[i].number === this.targetNumberToHit) {
						this.activeTargets[i].CookieTargetHighlight.gotoAndPlay("Pulse");
					}
				}
			}
			
		}

		if (!this.playingIncorrectFeedback) {
			// don't interrupt incorrect feedback
			this.playingIncorrectFeedback = true;
			this.voPlayer.play(feedbackVo, (function(){
				this.playingIncorrectFeedback = false;
			}.bind(this)));
		}
		

		// analytics for wrong answer
		var paddedTargetNumber = GA_obj.valueToPaddedString(this.targetNumberToHit),
		paddedHintNumber = GA_obj.valueToPaddedString(this.currentWrongAnswerCount, 2, 3);

		GA_obj.trackEvent("Archery Hint", "Target_" + paddedTargetNumber + " Hint_" + paddedHintNumber, this.currentWrongAnswerCount);

		this.ricochetingArrows.push(this.activeArrows.shift());

		var xTo = this.ricochetingArrows[this.ricochetingArrows.length - 1].x + 50;
		var yTo = 620;
		var rotateTo = -450;

		createjs.Tween.get(this.ricochetingArrows[this.ricochetingArrows.length - 1]).to({y: yTo, x: xTo, rotation: rotateTo, alpha: 0}, this.arrowFlightTime).call(this.onArrowBounceComplete);
	};

	p.onArrowBounceComplete = function()
	{
		this.arrowPool.push(this.ricochetingArrows.shift());
		this.panel.skin.removeChild(this.arrowPool[this.arrowPool.length - 1]);
	};

	p.onBack = function()
	{
		var eventLabel = this.completeScreenVisible === true ? "Archery_Complete Screen" : "Archery";
		GA_obj.trackEvent("button home", eventLabel);
		this.onResetInactivityTimeout();
		this.onStopGameplay();

		this.previousState();
	};

	p.onReplay = function()
	{
		this.onResetInactivityTimeout();
		app.config.globalState.gamePlayData.archeryGame.consecutivePlays += 1;

		var rawNumber = app.config.globalState.gamePlayData.archeryGame.consecutivePlays + 1, 
		paddedNumber = GA_obj.valueToPaddedString(rawNumber);

		GA_obj.trackEvent("replay", "Archery Replays_" + paddedNumber, rawNumber);

		this._nextState = "archeryGame";
		this.nextState();
	};

	p.onHome = function() {
		var eventLabel = this.completeScreenVisible === true ? "Archery_Complete Screen" : "Archery";
		GA_obj.trackEvent("button home", eventLabel);
		this.onResetInactivityTimeout();
		this.previousState();
	};

	p.onGameEnd = function()
	{
		app.config.globalState.gamePlayData.archeryGame.totalPlays += 1;
		app.config.globalState.lastCompletedGame = "archeryGame";

		// Target_[01-07] Shots_[Number of shots fired based on input from user] Hits_[Numer of shots that hit correct target]

		var paddedPlays = GA_obj.valueToPaddedString(app.config.globalState.gamePlayData.archeryGame.totalPlays),
		paddedTargetsHit = GA_obj.valueToPaddedString(this.targetHitCount),
		paddedTargetNumber = GA_obj.valueToPaddedString(this.targetNumberToHit),
		paddedShotsFired = GA_obj.valueToPaddedString(this.shotsFired);

		GA_obj.trackEvent("Archery", "Plays_" + paddedPlays, app.config.globalState.gamePlayData.archeryGame.totalPlays);
		GA_obj.trackEvent("Archery Info", "Target_" + paddedTargetNumber + " Shots_" + paddedShotsFired + " Hits_" + paddedTargetsHit, this.shotsFired);

		this.onStopGameplay();

		app.sound.play("applause");

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}

		this.panel.bow.visible = false;

		this.panel.skin.CookieMonsterVictory.visible = true;
        this.panel.skin.CookieMonsterVictory.play();

		this.wrapUpTimeout = new Delay(this.onWrapUpComplete, 3000);
	};

	p.onWrapUpComplete = function()
	{
		this.panel.createScorePanel(this.targetHitCount.toString());
		this.completeScreenVisible = true;

		// display score
		this.panel.replayButton.addEventListener("click", this.onReplay);
		this.panel.homeButton.addEventListener("click", this.onHome);

		var yTo = 10 * app.scaling.scale;
		this.panel.scoreScreen.y = 780;
		createjs.Tween.get(this.panel.scoreScreen).to({y: yTo}, 600, createjs.Ease.backOut);

		this.panel.backButton.alpha = 0;

		var completeScreenVo = [];

		if (this.targetHitCount > 0) {
			completeScreenVo.push("CG_31");
			completeScreenVo.push("CG_" + (app.config.userSettings.numberVoOffsets.final + this.targetHitCount));
		}

		// decide grovers VO lines based on score
		if (this.targetHitCount > 15) {
			completeScreenVo.push("CG_60");
		} else if (this.targetHitCount > 0) {
			var voString = DL_Util.randPosNeg() > 0 ? "CG_61" : "CG_62";
			completeScreenVo.push(voString);
		} else {
			completeScreenVo.push("CG_63");
		}

        this.panel.skin.CookieMonsterVictory.stop();
		this.voPlayer.play(completeScreenVo, this.fireCompleteScreenButtonPrompt);
	};

	p.onCharacterReact = function(force)
	{
		this.actionsSinceLastReaction += 1;

		if ( (this.actionsSinceLastReaction >= 3 && this.voPlayer.playing === false) || force ) {
			this.actionsSinceLastReaction = 0;
			var reactionNumber = DL_Util.getRandomInt(1, 20) + app.config.userSettings.numberVoOffsets.react;
			this.voPlayer.play("CG_" + reactionNumber);
		}
	};

	p.fireGameplayPrompt = function()
	{
		var timeoutVo = [];
		if (app.config.globalState.consecutiveTimeouts === 1) {
			// timeout 1
			var voString = DL_Util.randPosNeg() > 0 ? "CG_39" : "CG_40";
			timeoutVo.push(voString);
			timeoutVo.push(app.config.globalState.inputPrompts.grover);
			timeoutVo.push("CG_69");
			timeoutVo.push("CG_" + (app.config.userSettings.numberVoOffsets.final + this.targetNumberToHit));
		} else {
			timeoutVo.push(app.config.globalState.inputPrompts.cookie);
			timeoutVo.push("CG_70");
		}
		this.voPlayer.play(timeoutVo, this.continueInactivityTimeout);
	};

	p.fireCompleteScreenButtonPrompt = function(timeout)
	{
		timeout = timeout || false;
		var completeScreenPrompts = [];

		if (timeout === true) {
			if (this.voPlayer.playing === true) {
				return;
			}
			completeScreenPrompts.push(app.config.globalState.inputPrompts.grover);
			completeScreenPrompts.push("CG_43");
			completeScreenPrompts.push(app.config.globalState.inputPrompts.grover);
			completeScreenPrompts.push("CG_44");
			this.voPlayer.play(completeScreenPrompts, this.continueInactivityTimeout);

			// tween highlights
			createjs.Tween.get(this.panel.replayButtonHighlight)
			.to({alpha: 1}, 200)
			.wait(2000)
			.to({alpha: 0}, 200);

			createjs.Tween.get(this.panel.homeButtonHighlight)
			.wait(3000)
			.to({alpha: 1}, 200)
			.wait(2000)
			.to({alpha: 0}, 200);
		} else {
			completeScreenPrompts.push("CG_68");
			completeScreenPrompts.push("CG_37");
			this.voPlayer.play(completeScreenPrompts, this.onResetInactivityTimeout);

			// tween highlights
			createjs.Tween.get(this.panel.replayButtonHighlight)
			.to({alpha: 1}, 200)
			.wait(2500)
			.to({alpha: 0}, 200);

			createjs.Tween.get(this.panel.homeButtonHighlight)
			.wait(3500)
			.to({alpha: 1}, 200)
			.wait(2000)
			.to({alpha: 0}, 200);
		}

	};

	p.onStopGameplay = function()
	{
		Ticker.removeEventListener('tick', this.onTick);

		// stop all tweens
		for (var i = 0; i < this.activeTargets.length; i++) {
			createjs.Tween.removeTweens(this.activeTargets[i]);
		}

		for (i = 0; i < this.activeArrows.length; i++) {
			createjs.Tween.removeTweens(this.activeArrows[i]);
			this.activeArrows[i].visible = false;
		}

		// cookie targets sometimes overlap cookie monster's victory pose. Prevent this by removing them.
		for (i = 0; i < this.activeTargets.length; i++) {
			this.panel.skin.removeChild(this.activeTargets[i]);
		}

		// stop timeout loops
		if (this.introSequence !== null) {
			this.introSequence.destroy();
		}

		if (this.introSequenceTween !== null) {
			createjs.Tween.removeTweens(app.states.archeryGame.introSequenceTween.target);
			app.states.archeryGame.introSequenceTween = null;
		}

		if (this.spawnTimeout !== null) {
			this.spawnTimeout.destroy();
		}

		if (this.spawnEndTimeout !== null) {
			this.spawnEndTimeout.destroy();
		}

		if (this.gameTimeout !== null) {
			this.gameTimeout.destroy();
		}

		// remove event listeners that don't directly reference children of this panel
		this.panel.stage.removeEventListener("stagemousemove", this.onChangeBowPosition);
		this.panel.removeEventListener("pressup", this.onFireArrow);
	};

	p.onInactivityTimeout = function() {
		if (app.manager.currentState.stateId !== "archeryGame") {
			return;
		}
		// play audio, etc.
		if (app.config.globalState.firstInactivityTimeoutTime === 0) {
			app.config.globalState.firstInactivityTimeoutTime = Date.now();
		}
		app.config.globalState.consecutiveTimeouts += 1;
		
		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		
		if (this.completeScreenVisible === true) {
			if (this.voPlayer.playing === true) {
				this.onResetInactivityTimeout();
				return;
			} else {
				this.fireCompleteScreenButtonPrompt(true);
			}
			
		} else {
			this.fireGameplayPrompt();
		}

		var timeInSeconds = Math.round((Date.now() - app.config.globalState.firstInactivityTimeoutTime) / 1000),
		paddedTimoutCount = GA_obj.valueToPaddedString(app.config.globalState.consecutiveTimeouts),
		eventLabel = this.completeScreenVisible === true ? "Archery_Complete Screen" : "Archery";
		GA_obj.trackEvent("TimeoutPlay", eventLabel + " Timeout_" + paddedTimoutCount, timeInSeconds);
	};

	p.continueInactivityTimeout = function()
	{
		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		this.inactivityTimeout = new Delay(this.onInactivityTimeout, app.config.userSettings.inactivityTimeoutDurations.default);
	};

	p.onResetInactivityTimeout = function() {
		// fired every time an interaction occurs
		if (app.config.globalState.firstInactivityTimeoutTime > 0) {
			var eventLabel = this.completeScreenVisible === true ? "Archery_Complete Screen" : "Archery";
			GA_obj.trackEvent("TOReEnage", eventLabel);
		}
		app.config.globalState.consecutiveTimeouts = 0;
		app.config.globalState.firstInactivityTimeoutTime = 0;

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		this.inactivityTimeout = new Delay(this.onInactivityTimeout, app.config.userSettings.inactivityTimeoutDurations.default);
	};

	/**
	 * When the state starts to exit, before transition
	 * @method  exitStart
	 */
	p.exitStart = function()
	{
		
	};

	p.exit = function()
	{
		// stop all tweens, remove dynamically generated objects from stage
		for (var i = 0; i < this.activeTargets.length; i++) {
			this.panel.skin.removeChild(this.activeTargets[i]);
		}

		for (i = 0; i < this.activeArrows.length; i++) {
			this.panel.skin.removeChild(this.activeArrows[i]);
		}

		for (i = 0; i < this.ricochetingArrows.length; i++) {
			this.panel.skin.removeChild(this.ricochetingArrows[i]);
		}

		for (i = 0; i < this.cookieCounters.length; i++) {
			this.panel.skin.removeChild(this.cookieCounters[i]);
		}
		// clear all references to dynamically generated objects
		this.targetPool = [];
		this.activeTargets = [];
		this.targetsToHit = [];
		this.arrowPool = [];
		this.activeArrows = [];
		this.ricochetingArrows = [];
		this.cookieCounters = [];

		// reset instance vars
		this.introComplete = false;
		this.targetHitCount = 0;
		this.shotsFired = 0;
		this.actionsSinceLastReaction = 0;
		this.currentWrongAnswerCount = 0;
		this.highlightsActive = false;
		this.adjustedTimeToCrossScreen = 18000;

		// remove temporary event listeners
		this.panel.backButton.removeEventListener("click", this.onBack);
		if (this.panel.replayButton) {
			this.panel.replayButton.removeEventListener("click", this.onReplay);
			this.panel.homeButton.removeEventListener("click", this.onHome);
		}

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}

		if (this.wrapUpTimeout !== null) {
			this.wrapUpTimeout.destroy();
		}
		app.config.globalState.firstInactivityTimeoutTime = 0;

		if (this.panel.replayButtonHighlight) {
			createjs.Tween.removeTweens(this.panel.replayButtonHighlight);
			createjs.Tween.removeTweens(this.panel.homeButtonHighlight);
		}
		
		app.sound.stop("applause");
		app.sound.stop("music_gameplayloop.L");
		this.voPlayer.stop();
	};

	//Assign to namespace
	namespace('PrimalScreen').ArcheryGameState = ArcheryGameState;
}());
(function()
{
	//Import classes
	var BaseState = include('springroll.easeljs.BaseState'),
		BreathingExercisePanel = include('PrimalScreen.BreathingExercisePanel');

	/**
	 * The logic for the game state
	 * @class PrimalScreen.BreathingExerciseState
	 * @extends springroll.easeljs.BaseState
	 */
	var BreathingExerciseState = function(options)
	{
		BaseState.call(this, new BreathingExercisePanel(), options);

		this.onSetup = this.onSetup.bind(this);
		this.onBack = this.onBack.bind(this);
		this.onStartBreathing = this.onStartBreathing.bind(this);
		this.onFinishBreathing = this.onFinishBreathing.bind(this);
		this.startSport = this.startSport.bind(this);

		this.BreathingExerciseTimeout = null;
	};

	//Extend the base state
	var p = extend(BreathingExerciseState, BaseState);

	p.onSetup = function()
	{
		this.panel.skin.gotoAndStop(0);
		this.panel.skin.BreathingMain.gotoAndStop(0);

		if (app.config.globalState.currentActiveGame === "ringGame") {
			this.panel.skin.BreathingMain.Background.gotoAndStop(0);
		} else if (app.config.globalState.currentActiveGame === "hurdleGame") {
			this.panel.skin.BreathingMain.Background.gotoAndStop(1);
		} else {
			// Archery game or no valid game defined
			this.panel.skin.BreathingMain.Background.gotoAndStop(2);
		}

		this.panel.skin.BreathingMain.CookieBreathing.gotoAndStop(app.config.globalState.currentCorrectEmotion);
	};

	/**
	 * After assets are loaded and state is fully entered
	 * @method  enterDone
	 */
	p.enterDone = function()
	{

		this.panel.backButton.addEventListener("click", this.onBack);

		if (app.config.globalState.currentCorrectEmotion === "overexcited") {
			this.panel.skin.BreathingMain.GroverInterview.gotoAndPlay("CG_26");
			this.voPlayer.play("CG_26", this.onStartBreathing); // overexcited specific vo line
		} else {
			this.panel.skin.BreathingMain.GroverInterview.gotoAndPlay("CG_25");
			this.voPlayer.play("CG_25", this.onStartBreathing);
		}
		
	};

	p.onBack = function()
	{
		GA_obj.trackEvent("button home", app.config.userSettings.analyticsStrings[app.config.globalState.currentActiveGame] + "_Emotion Choice Screen");
		this.previousState();
	};

	p.onStartBreathing = function()
	{
		this.panel.skin.gotoAndStop(1);
		this.panel.skin.BreathingMain.gotoAndStop(1);
		this.panel.skin.BreathingMain.GroverInterview.gotoAndStop(0);
		this.panel.skin.BreathingMain.CookieBreathing.gotoAndPlay(0);
		this.voPlayer.play("CG_28", this.onFinishBreathing);
	};

	p.onFinishBreathing = function()
	{
		var introVo = [];

		if (app.config.globalState.currentActiveGame === "ringGame") {
			introVo.push("CG_29");
			this.panel.skin.BreathingMain.GroverInterview.gotoAndPlay("CG_29");
		} else if (app.config.globalState.currentActiveGame === "hurdleGame") {
			introVo.push("CG_46");
			this.panel.skin.BreathingMain.GroverInterview.gotoAndPlay("CG_46");
		} else if (app.config.globalState.currentActiveGame === "archeryGame") {
			introVo.push("CG_56");
			this.panel.skin.BreathingMain.GroverInterview.gotoAndPlay("CG_56");
		}

		this.panel.skin.gotoAndStop(0);
		this.panel.skin.BreathingMain.gotoAndStop(0);
		this.panel.skin.BreathingMain.CookieBreathing.gotoAndStop(this.panel.skin.BreathingMain.CookieBreathing.timeline.duration - 7);
		this.voPlayer.play(introVo, this.startSport);
	};

	p.startSport = function()
	{
		this.panel.skin.BreathingMain.GroverInterview.gotoAndStop(0);

		this._nextState = app.config.globalState.currentActiveGame;

		this.nextState();
	};

	/**
	 * When the state starts to exit, before transition
	 * @method  exitStart
	 */
	p.exitStart = function()
	{
		if (this.BreathingExerciseTimeout !== null) {
			clearTimeout(this.BreathingExerciseTimeout);
		}
		this.voPlayer.stop();
	};

	//Assign to namespace
	namespace('PrimalScreen').BreathingExerciseState = BreathingExerciseState;
}());
(function()
{
	//Import classes
	var BaseState = include('springroll.easeljs.BaseState'),
		Sound = include('springroll.Sound'),
		Delay = include('springroll.DelayedCall'),
		EmotionIdentificationPanel = include('PrimalScreen.EmotionIdentificationPanel');

	/**
	 * The logic for the game state
	 * @class PrimalScreen.EmotionIdentificationState
	 * @extends springroll.easeljs.BaseState
	 */
	var EmotionIdentificationState = function(options)
	{
		BaseState.call(this, new EmotionIdentificationPanel(), options);

		this.onSetup = this.onSetup.bind(this);
		this.onBack = this.onBack.bind(this);
		this.onSelectEmotion = this.onSelectEmotion.bind(this);
		this.onEmotionHoverOver = this.onEmotionHoverOver.bind(this);
		this.onEmotionHoverOut = this.onEmotionHoverOut.bind(this);
		this.onEmotionAudition = this.onEmotionAudition.bind(this);
		this.onShowEmotionSelect = this.onShowEmotionSelect.bind(this);
		this.onCorrectEmotionSelect = this.onCorrectEmotionSelect.bind(this);
		this.onInactivityTimeout = this.onInactivityTimeout.bind(this);
		this.onIncorrectFeedbackComplete = this.onIncorrectFeedbackComplete.bind(this);
		this.onResetInactivityTimeout = this.onResetInactivityTimeout.bind(this);
		this.playIntroVo = this.playIntroVo.bind(this);
		this.onEmotionSelectIntroComplete = this.onEmotionSelectIntroComplete.bind(this);
		this.onEmotionSelectHighlightsComplete = this.onEmotionSelectHighlightsComplete.bind(this);
		this.animateCookieMonsterResponse = this.animateCookieMonsterResponse.bind(this);

		this.inactivityTimeout = null;

		this.emotionIdentificationTimeout = null;
		this.emotionAuditionTimeout = null;
		this.emotionBeingAuditioned = null;
		this.EmotionIdentificationAttempts = 0;
		this.allowEmotionAuditioning = false;
	};

	//Extend the base state
	var p = extend(EmotionIdentificationState, BaseState);

	p.onSetup = function()
	{
		this.panel.skin.gotoAndStop(0);
		this.panel.skin.EmotionsMain.gotoAndStop(0);
		if (app.config.globalState.currentActiveGame === "ringGame") {
			this.panel.skin.EmotionsMain.Background.gotoAndStop(0);
		} else if (app.config.globalState.currentActiveGame === "hurdleGame") {
			this.panel.skin.EmotionsMain.Background.gotoAndStop(1);
		} else {
			// Archery game or no valid game defined
			this.panel.skin.EmotionsMain.Background.gotoAndStop(2);
		}

		this.emotionSet = [];
		this.emotionSet.push(app.config.globalState.correctEmotionOrder.shift());

		if (app.config.globalState.currentActiveGame === "archeryGame" && this.emotionSet[0] === "scared") {
			this.emotionSet = [];
			this.emotionSet.push(app.config.globalState.correctEmotionOrder.shift());
		}

		app.config.globalState.correctEmotionOrder.push(this.emotionSet[0]);
		app.config.globalState.currentCorrectEmotion = this.emotionSet[0];
		// set cookie monster's emotion to not be neutral
		this.panel.skin.EmotionsMain.CookieMonsterEmotions.gotoAndStop(app.config.globalState.currentCorrectEmotion);

		this.emotionSet.push(app.config.userSettings.emotionLabelCombinations[this.emotionSet[0]][0]);
		this.emotionSet.push(app.config.userSettings.emotionLabelCombinations[this.emotionSet[0]][1]);

		DL_Util.shuffle(this.emotionSet); // randomize the emotion order

		this.panel.skin.EmotionsMain.CookieMonsterEmotions.stop();
	};

	/**
	 * After assets are loaded and state is fully entered
	 * @method  enterDone
	 */
	p.enterDone = function()
	{

		this.panel.backButton.addEventListener("click", this.onBack);

		// this.emotionIdentificationTimeout = new Delay(this.onShowEmotionSelect, 3000);
		this.EmotionIdentificationAttempts = 0;
		this.allowEmotionAuditioning = false;

		app.config.globalState.mostRecentScreen = app.config.userSettings.analyticsStrings[app.config.globalState.currentActiveGame];

		this.playIntroVo();
	};

	p.onBack = function()
	{
		GA_obj.trackEvent("button home", app.config.userSettings.analyticsStrings[app.config.globalState.currentActiveGame] + "_Emotion Choice Screen");
		this.onResetInactivityTimeout();
		this.previousState();
	};

	p.playIntroVo = function()
	{
		var introVo = [];

		if (app.config.globalState.currentActiveGame === "ringGame") {
			introVo.push("CG_14");
			this.panel.skin.EmotionsMain.GroverInterview.gotoAndPlay("CG_14");
		} else if (app.config.globalState.currentActiveGame === "hurdleGame") {
			introVo.push("CG_45");
			this.panel.skin.EmotionsMain.GroverInterview.gotoAndPlay("CG_45");
		} else if (app.config.globalState.currentActiveGame === "archeryGame") {
			introVo.push("CG_55");
			this.panel.skin.EmotionsMain.GroverInterview.gotoAndPlay("CG_55");
		}

		// introVo.push(app.config.userSettings.emotionVoIds[app.config.globalState.currentCorrectEmotion].emotionDescription);
		this.voPlayer.play(introVo, this.animateCookieMonsterResponse);
	};

	p.animateCookieMonsterResponse = function()
	{
		var responseVo = [];
		responseVo.push(app.config.userSettings.emotionVoIds[app.config.globalState.currentCorrectEmotion].emotionDescription);
		responseVo.push(2000);

		this.panel.skin.gotoAndStop(1);
		this.panel.skin.EmotionsMain.gotoAndStop("CU");
		this.panel.skin.EmotionsMain.GroverInterview.gotoAndStop(0);
		this.panel.skin.EmotionsMain.CookieMonsterEmotions.gotoAndPlay(app.config.globalState.currentCorrectEmotion);
		this.voPlayer.play(responseVo, this.onShowEmotionSelect);
	};

	p.onShowEmotionSelect = function()
	{

		this.panel.createEmotionSelectPanel(this.emotionSet);

		this.panel.emotionOptionOne.addEventListener("click", this.onSelectEmotion);
		this.panel.emotionOptionTwo.addEventListener("click", this.onSelectEmotion);
		this.panel.emotionOptionThree.addEventListener("click", this.onSelectEmotion);

		if (!app.hasTouch) {
			// add pause ons, since we can hover
			this.panel.emotionOptionOne.addEventListener("mouseover", this.onEmotionHoverOver);
			this.panel.emotionOptionTwo.addEventListener("mouseover", this.onEmotionHoverOver);
			this.panel.emotionOptionThree.addEventListener("mouseover", this.onEmotionHoverOver);

			this.panel.emotionOptionOne.addEventListener("mouseout", this.onEmotionHoverOut);
			this.panel.emotionOptionTwo.addEventListener("mouseout", this.onEmotionHoverOut);
			this.panel.emotionOptionThree.addEventListener("mouseout", this.onEmotionHoverOut);
		}

		this.panel.emotionOptionOne._stateFlags.disabled = false;
		this.panel.emotionOptionTwo._stateFlags.disabled = false;
		this.panel.emotionOptionThree._stateFlags.disabled = false;

		this.panel.emotionOptionOne._stateFlags.unused = false;
		this.panel.emotionOptionTwo._stateFlags.unused = false;
		this.panel.emotionOptionThree._stateFlags.unused = false;

		this.panel.emotionChoices.y = 780;
		var yTo = 100 * app.scaling.scale;
		createjs.Tween.get(this.panel.emotionChoices).to({y: yTo}, 600, createjs.Ease.backOut);

		app.config.globalState.firstInactivityTimeoutTime = 0;
		this.onResetInactivityTimeout();

		this.voPlayer.play("CG_21", this.onEmotionSelectIntroComplete);
	};

	p.onEmotionSelectIntroComplete = function()
	{

		var groverEmotionReads = [];
		groverEmotionReads.push(app.config.userSettings.emotionVoIds[this.emotionSet[0]].grover);
		groverEmotionReads.push(1);
		groverEmotionReads.push(app.config.userSettings.emotionVoIds[this.emotionSet[1]].grover);
		groverEmotionReads.push(1);
		groverEmotionReads.push(app.config.userSettings.emotionVoIds[this.emotionSet[2]].grover);

		// add highlight tweens
		createjs.Tween.get(this.panel.emotionHighlightOne)
			.to({alpha: 1}, 200)
			.wait(1000)
			.to({alpha: 0}, 200);

		createjs.Tween.get(this.panel.emotionHighlightTwo)
			.wait(1200)
			.to({alpha: 1}, 200)
			.wait(1000)
			.to({alpha: 0}, 200);
		createjs.Tween.get(this.panel.emotionHighlightThree)
			.wait(2400)
			.to({alpha: 1}, 200)
			.wait(1000)
			.to({alpha: 0}, 200);

		this.voPlayer.play(groverEmotionReads, this.onEmotionSelectHighlightsComplete);
	};

	p.onEmotionSelectHighlightsComplete = function() {
		this.allowEmotionAuditioning = true;
	};

	p.onSelectEmotion = function(event)
	{
		this.onResetInactivityTimeout();

		if ( (event.target._stateFlags.disabled === true || event.target._stateFlags.unused === true) && event.target._stateFlags.correct === false) {
			// this button has been disabled. Send an analytics event, but otherwise ignore it.
			emotionMatchString = "Disabled " + event.target.emotionName + " Attempt_0" + this.EmotionIdentificationAttempts;
			GA_obj.trackEvent("emotion match", emotionMatchString);
			return;
		} else if (event.target._stateFlags.correct === true) {
			// don't let them select multiple correct answers, just exit
			return;
		}

		this.EmotionIdentificationAttempts += 1;
		var emotionMatchString = ''; // because jsHint yells at us

		var emotionSelectVo = [];

		if (event.target.emotionName === app.config.globalState.currentCorrectEmotion) {
			// correct answer
			event.target._stateFlags.correct = true;
			this.allowEmotionAuditioning = false;

			if (this.panel.emotionHighlightOne) {
				createjs.Tween.removeTweens(this.panel.emotionHighlightOne);
				this.panel.emotionHighlightOne.alpha = 0;
				createjs.Tween.removeTweens(this.panel.emotionHighlightTwo);
				this.panel.emotionHighlightTwo.alpha = 0;
				createjs.Tween.removeTweens(this.panel.emotionHighlightThree);
				this.panel.emotionHighlightThree.alpha = 0;
			}

			if (event.target === this.panel.emotionOptionOne) {
				this.panel.emotionHighlightOne.x -= 10;
				this.panel.emotionHighlightOne.y += 10;
				this.panel.emotionHighlightOne.alpha = 1;
			}
			if (event.target === this.panel.emotionOptionTwo) {
				this.panel.emotionHighlightTwo.x -= 10;
				this.panel.emotionHighlightTwo.y += 10;
				this.panel.emotionHighlightTwo.alpha = 1;
			}
			if (event.target === this.panel.emotionOptionThree) {
				this.panel.emotionHighlightThree.x -= 10;
				this.panel.emotionHighlightThree.y += 10;
				this.panel.emotionHighlightThree.alpha = 1;
			}

			this.panel.emotionOptionOne._stateFlags.unused = true;
			this.panel.emotionOptionTwo._stateFlags.unused = true;
			this.panel.emotionOptionThree._stateFlags.unused = true;

			// always add a leading zero, since attempt number can never go above three
			emotionMatchString = "Correct " + event.target.emotionName + " Attempt_0" + this.EmotionIdentificationAttempts;
			GA_obj.trackEvent("emotion match", emotionMatchString);

			// this.emotionIdentificationTimeout = new Delay(this.onCorrectEmotionSelect, 1000);

			emotionSelectVo.push("bellyes");
			emotionSelectVo.push("CG_22");
			emotionSelectVo.push("CG_23");
			emotionSelectVo.push(app.config.userSettings.emotionVoIds[app.config.globalState.currentCorrectEmotion].grover);
			emotionSelectVo.push(app.config.userSettings.emotionVoIds[app.config.globalState.currentCorrectEmotion].sound);
			emotionSelectVo.push(1000);

			this.voPlayer.play(emotionSelectVo, this.onCorrectEmotionSelect);

		} else {
			this.allowEmotionAuditioning = false;
			event.target._stateFlags.disabled = true;

			emotionSelectVo.push("hurdlebounce");
			if (this.EmotionIdentificationAttempts === 1) {
				emotionSelectVo.push("CG_71");
			} else {
				emotionSelectVo.push(app.config.userSettings.emotionVoIds[app.config.globalState.currentCorrectEmotion].emotionDescriptionFinal);
			}
			this.voPlayer.play(emotionSelectVo, this.onIncorrectFeedbackComplete);

			emotionMatchString = "Incorrect " + event.target.emotionName + " Attempt_0" + this.EmotionIdentificationAttempts;
			GA_obj.trackEvent("emotion match", emotionMatchString);
			return;
		}
		// this._nextState = app.config.globalState.currentActiveGame;

		// this.nextState();
	};

	p.onIncorrectFeedbackComplete = function()
	{
		this.allowEmotionAuditioning = true;
	};

	// pause ons
	p.onEmotionHoverOver = function(event)
	{
		if (event.target._stateFlags.disabled === true || event.target._stateFlags.unused === true || event.target._stateFlags.correct === true) {
			return;
		}
		this.emotionBeingAuditioned = event.target.emotionName;
		this.emotionAuditionTimeout = new Delay(this.onEmotionAudition, app.config.userSettings.emotionLabelPauseOnDuration);
		this.onResetInactivityTimeout();
	};

	p.onEmotionAudition = function() {
		// play vo here
		if (this.allowEmotionAuditioning === false) {
			// don't interrupt. rude.
			return;
		}
		// remove highlight tweens, if running
		createjs.Tween.removeTweens(this.panel.emotionHighlightOne);
		this.panel.emotionHighlightOne.alpha = 0;
		createjs.Tween.removeTweens(this.panel.emotionHighlightTwo);
		this.panel.emotionHighlightTwo.alpha = 0;
		createjs.Tween.removeTweens(this.panel.emotionHighlightThree);
		this.panel.emotionHighlightThree.alpha = 0;

		this.voPlayer.play(app.config.userSettings.emotionVoIds[this.emotionBeingAuditioned].grover);

		// track emotion auditioned
		GA_obj.trackEvent("emotion audition", this.emotionBeingAuditioned);
	};

	p.onEmotionHoverOut = function() {
		if (this.emotionAuditionTimeout !== null) {
			this.emotionAuditionTimeout.destroy();
		}
	};

	p.onCorrectEmotionSelect = function()
	{
		this.nextState();
	};

	p.onInactivityTimeout = function() {
		// play audio, etc.
		if (this.allowEmotionAuditioning === false) {
			this.onResetInactivityTimeout();
			return;
		}
		if (app.config.globalState.firstInactivityTimeoutTime === 0) {
			app.config.globalState.firstInactivityTimeoutTime = Date.now();
		}
		app.config.globalState.consecutiveTimeouts += 1;

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		this.inactivityTimeout = new Delay(this.onInactivityTimeout, app.config.userSettings.inactivityTimeoutDurations.default);
		var timeoutVo = [];
		if (app.config.globalState.consecutiveTimeouts % 2 === 1) {

			timeoutVo.push(app.config.globalState.inputPrompts.grover);
			timeoutVo.push("CG_38");

		} else {
			timeoutVo.push(app.config.userSettings.emotionVoIds[app.config.globalState.currentCorrectEmotion].emotionDescriptionFinal);
		}
		this.voPlayer.play(timeoutVo);

		var timeInSeconds = Math.round((Date.now() - app.config.globalState.firstInactivityTimeoutTime) / 1000),
		paddedTimoutCount = GA_obj.valueToPaddedString(app.config.globalState.consecutiveTimeouts);
		GA_obj.trackEvent("TimeoutPlay", app.config.userSettings.analyticsStrings[app.config.globalState.currentActiveGame] + "_Emotion Choice Screen Timeout_" + paddedTimoutCount, timeInSeconds);
	};

	p.onResetInactivityTimeout = function() {
		// fired every time an interaction occurs
		if (app.config.globalState.firstInactivityTimeoutTime > 0) {
			var timeInSeconds = Math.round((Date.now() - app.config.globalState.firstInactivityTimeoutTime) / 1000),
			paddedTimoutCount = GA_obj.valueToPaddedString(app.config.globalState.consecutiveTimeouts);
			GA_obj.trackEvent("TOReEnage", app.config.userSettings.analyticsStrings[app.config.globalState.currentActiveGame] + "_Emotion Choice Screen");
		}
		app.config.globalState.consecutiveTimeouts = 0;
		app.config.globalState.firstInactivityTimeoutTime = 0;

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		this.inactivityTimeout = new Delay(this.onInactivityTimeout, app.config.userSettings.inactivityTimeoutDurations.default);
	};

	/**
	 * When the state starts to exit, before transition
	 * @method  exitStart
	 */
	p.exitStart = function()
	{
		if (this.emotionIdentificationTimeout !== null) {
			this.emotionIdentificationTimeout.destroy();
		}
		if (this.emotionAuditionTimeout !== null) {
			this.emotionAuditionTimeout.destroy();
		}

		if (this.panel.emotionOptionOne) {
			this.panel.emotionOptionOne.removeAllEventListeners();
			this.panel.emotionOptionTwo.removeAllEventListeners();
			this.panel.emotionOptionThree.removeAllEventListeners();
		}

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		app.config.globalState.firstInactivityTimeoutTime = 0;

		if (this.panel.emotionHighlightOne) {
			createjs.Tween.removeTweens(this.panel.emotionHighlightOne);
			this.panel.emotionHighlightOne.alpha = 0;
			createjs.Tween.removeTweens(this.panel.emotionHighlightTwo);
			this.panel.emotionHighlightTwo.alpha = 0;
			createjs.Tween.removeTweens(this.panel.emotionHighlightThree);
			this.panel.emotionHighlightThree.alpha = 0;
		}

		this.EmotionIdentificationAttempts = 0;
		this.allowEmotionAuditioning = false;
		this.voPlayer.stop();
		
	};

	//Assign to namespace
	namespace('PrimalScreen').EmotionIdentificationState = EmotionIdentificationState;
}());
(function()
{
	//Import classes
	var BaseState = include('springroll.easeljs.BaseState'),
		FinalePanel = include('PrimalScreen.FinalePanel');
		Delay = include('springroll.DelayedCall');

	/**
	 * The logic for the game state
	 * @class PrimalScreen.FinaleState
	 * @extends springroll.easeljs.BaseState
	 */
	var FinaleState = function(options)
	{
		BaseState.call(this, new FinalePanel(), options);

		this.onBack = this.onBack.bind(this);
		this.finaleSequence1 = this.finaleSequence1.bind(this);
		this.finaleSequence2 = this.finaleSequence2.bind(this);
		this.finaleSequence3 = this.finaleSequence3.bind(this);
		this.finaleSequence4 = this.finaleSequence4.bind(this);
		this.finaleSequenceComplete = this.finaleSequenceComplete.bind(this);

	};

	//Extend the base state
	var p = extend(FinaleState, BaseState);

	/**
	 * After assets are loaded and state is fully entered
	 * @method  enterDone
	 */
	p.enterDone = function()
	{

		this.finalTimeout = null;
		this.panel.backButton.addEventListener("click", this.onBack);

		// reset checkmarks
		app.config.globalState.gamePlayData.ringGame.hasCheckmark = false;
		app.config.globalState.gamePlayData.hurdleGame.hasCheckmark = false;
		app.config.globalState.gamePlayData.archeryGame.hasCheckmark = false;

		// var finaleVo = [];
		// finaleVo.push("CG_78");
		// finaleVo.push("CG_79");
		// finaleVo.push("CG_80");
		// finaleVo.push("CG_81");
		// finaleVo.push(2);
		// this.voPlayer.play(finaleVo, this.onBack);

		// this.panel.skin.instance.play();

		this.finaleSequence1();
	};

	p.finaleSequence1 = function()
	{
		this.voPlayer.play("CG_78", this.finaleSequence2);
		this.panel.skin.instance.gotoAndPlay("Finale_Grover_1");
	};

	p.finaleSequence2 = function()
	{
		this.voPlayer.play("CG_79", this.finaleSequence3);
		this.panel.skin.instance.gotoAndPlay("Finale_Cookie_1");
	};

	p.finaleSequence3 = function()
	{
		this.voPlayer.play("CG_80", this.finaleSequence4);
		this.panel.skin.instance.gotoAndPlay("Finale_Grover_2");
	};

	p.finaleSequence4 = function()
	{
		this.voPlayer.play("CG_81", this.finaleSequenceComplete);
		this.panel.skin.instance.gotoAndPlay("Finale_Cookie_2");
	};

	p.finaleSequenceComplete = function()
	{
		this.finalTimeout = new Delay(this.onBack, 3000);
	};

	p.onBack = function()
	{
		this.previousState();
	};

	/**
	 * When the state starts to exit, before transition
	 * @method  exitStart
	 */
	p.exitStart = function()
	{
		this.voPlayer.stop();
		if (this.finalTimeout !== null) {
			this.finalTimeout.destroy();
		}
	};

	//Assign to namespace
	namespace('PrimalScreen').FinaleState = FinaleState;
}());
(function()
{
	//Import classes
	var BaseState = include('springroll.easeljs.BaseState'),
		Bitmap = include('createjs.Bitmap'),
		Delay = include('springroll.DelayedCall'),
		GameSelectPanel = include('PrimalScreen.GameSelectPanel');

	/**
	 * The logic for the game state
	 * @class PrimalScreen.GameSelectState
	 * @extends springroll.easeljs.BaseState
	 */
	var GameSelectState = function(options)
	{
		BaseState.call(this, new GameSelectPanel(), options);

		this.selectEvent = this.selectEvent.bind(this);
		this.checkCheckboxes = this.checkCheckboxes.bind(this);
		this.onCheckboxesChecked = this.onCheckboxesChecked.bind(this);
		this.onBack = this.onBack.bind(this);
		this.onInactivityTimeout = this.onInactivityTimeout.bind(this);
		this.onResetInactivityTimeout = this.onResetInactivityTimeout.bind(this);
		this.onSportAudition = this.onSportAudition.bind(this);
		this.onSportHoverOver = this.onSportHoverOver.bind(this);
		this.onSportHoverOut = this.onSportHoverOut.bind(this);
		this.playIntroVo = this.playIntroVo.bind(this);
		this.askWhichSport = this.askWhichSport.bind(this);
		this.onIntroComplete = this.onIntroComplete.bind(this);
		this.disableInteractions = this.disableInteractions.bind(this);

		this.checkboxDelay = null;
		this.inactivityTimeout = null;
		this.sportAuditionTimeout = null;
	};

	//Extend the base state
	var p = extend(GameSelectState, BaseState);

	/**
	 * After assets are loaded and state is fully entered
	 * @method  enterDone
	 */
	p.enterDone = function()
	{

		app.sound.play("music_shortloop.L");

		app.config.globalState.currentActiveGame = "none"; // reset the active game
		app.config.globalState.mostRecentScreen = "Sport Select Screen";

		// reset any consecutive counts
		app.config.globalState.gamePlayData.ringGame.consecutivePlays = 0;
		app.config.globalState.gamePlayData.hurdleGame.consecutivePlays = 0;
		app.config.globalState.gamePlayData.archeryGame.consecutivePlays = 0;

		// add checkboxes to items that already have them? Or do this in the panel...


		// Add new checkbox
		this.checkCheckboxes();
	};

	p.checkCheckboxes = function()
	{

		if (app.config.globalState.lastCompletedGame !== "none" && app.config.globalState.gamePlayData[app.config.globalState.lastCompletedGame].hasCheckmark === false) {
			// add checkmark graphic

			app.sound.play("bellyes");
			app.config.globalState.gamePlayData[app.config.globalState.lastCompletedGame].hasCheckmark = true;
			var buttonName = app.config.globalState.lastCompletedGame + "Button";
			this.panel.addCheckmark(this.panel[buttonName], true);
			this.checkboxDelay = new Delay(this.onCheckboxesChecked, 1000);
		} else {
			this.onCheckboxesChecked();
		}

		app.config.globalState.lastCompletedGame = "none";
		
	};

	p.onCheckboxesChecked = function()
	{	
		if (app.config.globalState.gamePlayData.ringGame.hasCheckmark && app.config.globalState.gamePlayData.hurdleGame.hasCheckmark && app.config.globalState.gamePlayData.archeryGame.hasCheckmark) {
			// all checkboxes checked - go to the finale!
			this._nextState = "finaleScene";

			this.nextState();
		} else {
			// missing a checkbox - let's not.
			this.panel.ringGameButton.addEventListener("click", this.selectEvent);
			this.panel.ringGameButton.enabled = true;
			this.panel.ringGameButton.eventName = "ringGame";

			this.panel.hurdleGameButton.addEventListener("click", this.selectEvent);
			this.panel.hurdleGameButton.enabled = true;
			this.panel.hurdleGameButton.eventName = "hurdleGame";

			this.panel.archeryGameButton.addEventListener("click", this.selectEvent);
			this.panel.archeryGameButton.enabled = true;
			this.panel.archeryGameButton.eventName = "archeryGame"; // change once these games exist

			this.playIntroVo();
		}
		
	};

	p.playIntroVo = function()
	{
		var introVo = [];

		if (app.config.globalState.hasSeenGameSelect === false) {
			// first time seeing sport select screen
			introVo.push("CG_3");
			introVo.push("CG_4");
			app.config.globalState.hasSeenGameSelect = true;
			this.voPlayer.play(introVo, this.askWhichSport);
			
		} else {
			// if we have already been to the sport select screen
			introVo.push("CG_12");

			var numberOfGamesPlayed = 0;

			// determine if we need to fire cookie monster's optional line here
			if (app.config.globalState.gamePlayData.ringGame.totalPlays > 0) {
				numberOfGamesPlayed += 1;
			}
			if (app.config.globalState.gamePlayData.hurdleGame.totalPlays > 0) {
				numberOfGamesPlayed += 1;
			}
			if (app.config.globalState.gamePlayData.archeryGame.totalPlays > 0) {
				numberOfGamesPlayed += 1;
			}
			if (numberOfGamesPlayed <= 1) {
				introVo.push("CG_13");
			}
			this.voPlayer.play(introVo, this.onIntroComplete);
		}

		
	};

	p.askWhichSport = function()
	{
		this.voPlayer.play("CG_5", this.onIntroComplete);
		// add highlight tweens
		createjs.Tween.get(this.panel.ringGameHighlight)
			.wait(2500)
			.to({alpha: 1}, 200)
			.wait(600)
			.to({alpha: 0}, 200);

		createjs.Tween.get(this.panel.hurdleGameHighlight)
			.wait(3500)
			.to({alpha: 1}, 200)
			.wait(600)
			.to({alpha: 0}, 200);
		createjs.Tween.get(this.panel.archeryGameHighlight)
			.wait(4500)
			.to({alpha: 1}, 200)
			.wait(600)
			.to({alpha: 0}, 200);
	};

	p.onIntroComplete = function()
	{
		if (!app.hasTouch) {
			// add pause ons, since we can hover
			this.panel.ringGameButton.addEventListener("mouseover", this.onSportHoverOver);
			this.panel.hurdleGameButton.addEventListener("mouseover", this.onSportHoverOver);
			this.panel.archeryGameButton.addEventListener("mouseover", this.onSportHoverOver);

			this.panel.ringGameButton.addEventListener("mouseout", this.onSportHoverOut);
			this.panel.hurdleGameButton.addEventListener("mouseout", this.onSportHoverOut);
			this.panel.archeryGameButton.addEventListener("mouseout", this.onSportHoverOut);
		}

		app.config.globalState.firstInactivityTimeoutTime = 0;
		this.onResetInactivityTimeout();
	};

	// pause ons
	p.onSportHoverOver = function(event)
	{
		this.sportBeingAuditioned = event.target.eventName;
		this.sportAuditionTimeout = new Delay(this.onSportAudition, app.config.userSettings.sportSelectPauseOnDuration);
		this.onResetInactivityTimeout();
	};

	p.onSportAudition = function() {
		// play vo here
		if (this.voPlayer.playing === true) {
			// don't interrupt grover's intro
			return;
		}
		if (this.sportBeingAuditioned === "ringGame") {
			this.voPlayer.play("CG_7");
		} else if (this.sportBeingAuditioned === "hurdleGame") {
			this.voPlayer.play("CG_8");
		} else if (this.sportBeingAuditioned === "archeryGame") {
			this.voPlayer.play("CG_6");
		}
	};

	p.onSportHoverOut = function() {
		if (this.sportAuditionTimeout !== null) {
			this.sportAuditionTimeout.destroy();
		}
	};

	p.selectEvent = function(event)
	{
		GA_obj.trackEvent("sport", app.config.userSettings.analyticsStrings[event.target.eventName]);
		this.onResetInactivityTimeout();

		app.config.globalState.currentActiveGame = event.target.eventName;
		if (app.config.userSettings.bypassSEL === true) {
			this._nextState = event.target.eventName;
		} else {
			this._nextState = "emotionIdentification";
		}

		this.disableInteractions();

		var sportVo = [];
		if (app.config.globalState.currentActiveGame === "ringGame") {
			sportVo.push("CG_7");
		} else if (app.config.globalState.currentActiveGame === "hurdleGame") {
			sportVo.push("CG_8");
		} else if (app.config.globalState.currentActiveGame === "archeryGame") {
			sportVo.push("CG_6");
		}
		sportVo.push(500);
		this.voPlayer.play(sportVo, (function(){
			this.nextState();
		}.bind(this)));

	};

	p.onInactivityTimeout = function() {
		// play audio, etc.

		if (app.config.globalState.firstInactivityTimeoutTime === 0) {
			app.config.globalState.firstInactivityTimeoutTime = Date.now();
		}
		app.config.globalState.consecutiveTimeouts += 1;

		var timeoutPromptLines = [];
		if (app.config.globalState.consecutiveTimeouts === 1) {
			timeoutPromptLines.push(app.config.globalState.inputPrompts.grover);
			timeoutPromptLines.push("CG_9");
		} else if (app.config.globalState.consecutiveTimeouts === 2) {
			timeoutPromptLines.push(app.config.globalState.inputPrompts.cookie);
			timeoutPromptLines.push("CG_10");
		} else {
			timeoutPromptLines.push(app.config.globalState.inputPrompts.grover);
			timeoutPromptLines.push("CG_11");
		}
		this.voPlayer.play(timeoutPromptLines);

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		this.inactivityTimeout = new Delay(this.onInactivityTimeout, app.config.userSettings.inactivityTimeoutDurations.default);

		var timeInSeconds = Math.round((Date.now() - app.config.globalState.firstInactivityTimeoutTime) / 1000),
		paddedTimoutCount = GA_obj.valueToPaddedString(app.config.globalState.consecutiveTimeouts);
		GA_obj.trackEvent("TimeoutPlay", "Sport select screen Timeout_" + paddedTimoutCount, timeInSeconds);
	};

	p.onResetInactivityTimeout = function() {
		// fired every time an interaction occurs
		if (app.config.globalState.firstInactivityTimeoutTime > 0) {
			var timeInSeconds = Math.round((Date.now() - app.config.globalState.firstInactivityTimeoutTime) / 1000),
			paddedTimoutCount = GA_obj.valueToPaddedString(app.config.globalState.consecutiveTimeouts);
			GA_obj.trackEvent("TOReEnage", "Sport select screen");
		}
		app.config.globalState.consecutiveTimeouts = 0;
		app.config.globalState.firstInactivityTimeoutTime = 0;

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		this.inactivityTimeout = new Delay(this.onInactivityTimeout, app.config.userSettings.inactivityTimeoutDurations.default);
	};

	p.onBack = function()
	{
		// Since the back button was removed, this event can never fire
		GA_obj.trackEvent("button home", "Sport select screen");
		this.onResetInactivityTimeout();
		this.previousState();
	};

	p.disableInteractions = function()
	{
		this.panel.ringGameButton.enabled = false;
		this.panel.hurdleGameButton.enabled = false;
		this.panel.archeryGameButton.enabled = false;

		this.panel.ringGameButton.removeEventListener("click", this.selectEvent);
		this.panel.hurdleGameButton.removeEventListener("click", this.selectEvent);
		this.panel.archeryGameButton.removeEventListener("click", this.selectEvent);

		if (!app.hasTouch) {
			// add pause ons, since we can hover
			this.panel.ringGameButton.removeEventListener("mouseover", this.onSportHoverOver);
			this.panel.hurdleGameButton.removeEventListener("mouseover", this.onSportHoverOver);
			this.panel.archeryGameButton.removeEventListener("mouseover", this.onSportHoverOver);

			this.panel.ringGameButton.removeEventListener("mouseout", this.onSportHoverOut);
			this.panel.hurdleGameButton.removeEventListener("mouseout", this.onSportHoverOut);
			this.panel.archeryGameButton.removeEventListener("mouseout", this.onSportHoverOut);
		}

		if (this.checkboxDelay !== null) {
			this.checkboxDelay.destroy();
		}

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}

		if (this.sportAuditionTimeout !== null) {
			this.sportAuditionTimeout.destroy();
		}
	};

	/**
	 * When the state starts to exit, before transition
	 * @method  exitStart
	 */
	p.exitStart = function()
	{
		this.disableInteractions();

		app.config.globalState.firstInactivityTimeoutTime = 0;
		// createjs.Tween.removeTweens(this.panel.ringGameButton);

		app.sound.stop("music_shortloop.L");
		this.voPlayer.stop();
	};

	//Assign to namespace
	namespace('PrimalScreen').GameSelectState = GameSelectState;
}());
(function()
{
	//Import classes
	var BaseState = include('springroll.easeljs.BaseState'),
		Ticker = include('createjs.Ticker'),
		Bitmap = include('createjs.Bitmap'),
		Delay = include('springroll.DelayedCall'),
		HurdleGamePanel = include('PrimalScreen.HurdleGamePanel');

	/**
	 * The logic for the game state
	 * @class PrimalScreen.HurdleGameState
	 * @extends springroll.easeljs.BaseState
	 */
	var HurdleGameState = function(options)
	{
		BaseState.call(this, new HurdleGamePanel(), options);

		this.onSetup = this.onSetup.bind(this);
		this.onBack = this.onBack.bind(this);
		this.onReplay = this.onReplay.bind(this);
		this.onHome = this.onHome.bind(this);
		this.onGameEnd = this.onGameEnd.bind(this);
		this.onStopGameplay = this.onStopGameplay.bind(this);
		this.onTick = this.onTick.bind(this);
		this.onPause = this.onPause.bind(this);
		this.onResume = this.onResume.bind(this);
		this.onCookieMonsterJump = this.onCookieMonsterJump.bind(this);
		this.sortFunction = this.sortFunction.bind(this);
		this.addHurdle = this.addHurdle.bind(this);
		this.addCookie = this.addCookie.bind(this);
		this.showFinishLine = this.showFinishLine.bind(this);
		this.collectCookie = this.collectCookie.bind(this);
		this.removeHurdle = this.removeHurdle.bind(this);
		this.removeCookie = this.removeCookie.bind(this);
		this.introInstructions = this.introInstructions.bind(this);
		this.onGameplayStart = this.onGameplayStart.bind(this);
		this.onWrapUpComplete = this.onWrapUpComplete.bind(this);
		this.fireCompleteScreenButtonPrompt = this.fireCompleteScreenButtonPrompt.bind(this);
		this.fireGameplayPrompt = this.fireGameplayPrompt.bind(this);
		this.onCharacterReact = this.onCharacterReact.bind(this);
		this.updateWorldVelocity = this.updateWorldVelocity.bind(this);
		this.updateWorldObjects = this.updateWorldObjects.bind(this);
		this.updateCookieJumpState = this.updateCookieJumpState.bind(this);
		this.checkHurdleCollisions = this.checkHurdleCollisions.bind(this);

		this.onInactivityTimeout = this.onInactivityTimeout.bind(this);
		this.continueInactivityTimeout = this.continueInactivityTimeout.bind(this);
		this.onResetInactivityTimeout = this.onResetInactivityTimeout.bind(this);

		this.completeScreenVisible = false;

		// tracking vars
		this.allowWorldUpdates = true;
		this.cookiesCollectedCount = 0;
		this.hurdlesKnockedOver = 0;
		this.timesJumped = 0;
		this.worldX = 0;
		this.currentVelocity = 0;
		this.groundVelocity = 0; // keep track of this, since we speed up cookie in the air
		this.currentDistanceBetweenHurdles = 0;
		this.currentCookiesSpawnedBetweenHurdles = 0;
		this.currentJumpVelocity = 0;
		this.nextHurdleToEngage = null;
		this.showingFinishLine = false;
		this.cookieMonsterState = "stopped"; // running, jumping, stopped
		this.actionsSinceLastReaction = 0;
		this.lastFrameUpdate = 0;
		this.gameplayStarted = false;

		this.activeHurdles = [];
		this.hurdlePool = [];
		this.activeCookies = [];
		this.cookiePool = [];

		this.gameTimeout = null;
		this.inactivityTimeout = null;
		this.wrapUpTimeout = null;
		this.finishLineTimeout = null;
	};

	//Extend the base state
	var p = extend(HurdleGameState, BaseState);

	p.onSetup = function()
	{
		// Set vars based on config
		this.runSpeedRange = app.config.userSettings.hurdleGameOptions.runSpeedRange;
		this.runSpeedIncrement = app.config.userSettings.hurdleGameOptions.runSpeedIncrement;
		this.maxRunSpeed = app.config.userSettings.hurdleGameOptions.maxRunSpeed;
		this.hurdleHitSpeed = app.config.userSettings.hurdleGameOptions.hurdleHitSpeed;
		this.distanceBetweenHurdles = app.config.userSettings.hurdleGameOptions.distanceBetweenHurdles; // how far do we have to scroll before encountering another hurdle
		this.cookiesBetweenHurdles = app.config.userSettings.hurdleGameOptions.cookiesBetweenHurdles;
		this.cookieSpawnPlacements = app.config.userSettings.hurdleGameOptions.cookieSpawnPlacements;
		this.acceleration = app.config.userSettings.hurdleGameOptions.acceleration;
		this.gravity = app.config.userSettings.hurdleGameOptions.gravity;
		this.jumpForce = app.config.userSettings.hurdleGameOptions.jumpForce;
		this.cookieMonsterYPos = app.config.userSettings.hurdleGameOptions.cookieMonsterYPos;

		// set time before finish line can be reached
		this.timeToSpawnFinishLine = app.config.userSettings.gameDurations.hurdles - ((1320 - (this.panel.skin.CookieMonsterRun.x / 2) + 150) / (this.maxRunSpeed * 60) * 1000);

		this.completeScreenVisible = false;
		this.allowWorldUpdates = true;

		this.panel.skin.tickEnabled = false; // We cannot change the sorting order of children without doing this

		this.panel.backButton.addEventListener("click", this.onBack);
		this.panel.backButton.alpha = 1;

		Ticker.addEventListener('tick', this.onTick);

		app.on("paused", this.onPause);
		app.on("resumed", this.onResume);

		this.addHurdle(800);
	};

	/**
	 * After assets are loaded and state is fully entered
	 * @method  enterDone
	 */
	p.enterDone = function()
	{	

		if (app.config.globalState.gamePlayData.hurdleGame.consecutivePlays === 0) {
			this.introInstructions();
		} else {
			this.onGameplayStart();
		}

		this.lastFrameUpdate = Date.now();
	};

	p.introInstructions = function()
	{
		this.cookieMonsterState = "stopped";

		var introVo = [
			app.config.globalState.inputPrompts.grover,
			"CG_47"
		];
		this.voPlayer.play(introVo, this.onGameplayStart);
	};

	p.onGameplayStart = function()
	{
		this.gameplayStarted = true;

		window.addEventListener("mousedown", this.onCookieMonsterJump);
		window.addEventListener("touchstart", this.onCookieMonsterJump);
		app.keyboard.addKeyDown("spacebar", this.onCookieMonsterJump);

		this.finishLineTimeout = new Delay(this.showFinishLine, this.timeToSpawnFinishLine);
		this.gameTimeout = new Delay(this.onGameEnd, app.config.userSettings.gameDurations.hurdles); // game timer

		this.panel.skin.CookieMonsterRun.tickEnabled = true;
		this.panel.skin.CookieMonsterRun.tickChildren = true;
		// this.panel.skin.CookieMonsterRun.play();
		this.cookieMonsterState = "running";

		app.sound.play("music_gameplayloop.L");

		// start the inactivity timeout for the first time
		app.config.globalState.firstInactivityTimeoutTime = 0;
		this.onResetInactivityTimeout();
	};

	p.onPause = function()
	{
		this.allowWorldUpdates = false;
	};

	p.onResume = function()
	{
		this.allowWorldUpdates = true;
	};

	/**
	 * Update loop for game logic, which fires every tick.
	 * @method  onTick
	 */
	p.onTick = function()
	{
		var frameDelta = (Date.now() - this.lastFrameUpdate) / (1000 / 60);
		this.lastFrameUpdate = Date.now();

		if (!this.allowWorldUpdates) {
			// game is paused, don't update positions
			return;
		}

		this.checkHurdleCollisions();

		// move background, position tracking, etc
		this.updateWorldVelocity(frameDelta);

		// cookie monster's vertical height and animation
		this.updateCookieJumpState(frameDelta);

		// move, spawn, and despawn cookies and hurdles
		this.updateWorldObjects(frameDelta);

		this.panel.skin.sortChildren(this.sortFunction);

	};

	p.checkHurdleCollisions = function()
	{
		// make sure we are checking the correct hurdle
		if (this.nextHurdleToEngage === null || this.nextHurdleToEngage.x - this.panel.skin.CookieMonsterRun.x < -this.distanceBetweenHurdles / 2) {
			for (i = 0; i < this.activeHurdles.length; i++) {
				if (this.activeHurdles[i].x > this.panel.skin.CookieMonsterRun.x) {
					this.nextHurdleToEngage = this.activeHurdles[i];
					break;
				}
			}
		}

		// check for hurdles in the way, knock them down
		// circle intersect
		if (this.nextHurdleToEngage.state === "up") {
			var hurdleCol = DL_Util.circleIntersect(this.panel.skin.CookieMonsterRun.x, 
				this.panel.skin.CookieMonsterRun.y, 
				this.panel.skin.CookieMonsterRun.nominalBounds.width / 3, 
				this.nextHurdleToEngage.x + (this.nextHurdleToEngage.nominalBounds.width / 2), 
				this.nextHurdleToEngage.y + (this.nextHurdleToEngage.nominalBounds.height / 3), 
				this.nextHurdleToEngage.nominalBounds.width / 4);

			if (hurdleCol === true) {
				this.hurdlesKnockedOver += 1;
				this.currentVelocity = this.hurdleHitSpeed;
				this.nextHurdleToEngage.gotoAndStop("Down");
				app.sound.play("hurdlehit");
				this.cookieMonsterState = "stopped";
				this.panel.skin.CookieMonsterRun.gotoAndStop("hit_stand");
			}
		}
	};

	p.updateCookieJumpState = function(frameDelta)
	{
		if (this.panel.skin.CookieMonsterRun.y < this.cookieMonsterYPos) {
			this.currentJumpVelocity += this.gravity * frameDelta;
			this.panel.skin.CookieMonsterRun.y += this.currentJumpVelocity * frameDelta;
		} else {
			this.panel.skin.CookieMonsterRun.y = this.cookieMonsterYPos;
			this.currentJumpVelocity = 0;
			if (this.cookieMonsterState === "jumping") {
				this.cookieMonsterState = "running";
				this.panel.skin.CookieMonsterRun.gotoAndStop("land");
			}
		}
	};

	p.updateWorldVelocity = function(frameDelta)
	{
		// accelerate the scroll speed
		if (this.cookieMonsterState === "stopped" || this.gameplayStarted === false) {
			this.groundVelocity = 0;
		} else if (this.groundVelocity < this.maxRunSpeed * app.scaling.scale) {
			this.groundVelocity += this.acceleration * app.scaling.scale;
		} else {
			this.groundVelocity = this.maxRunSpeed * app.scaling.scale;
		}

		if (this.panel.skin.CookieMonsterRun.y < this.cookieMonsterYPos) {
			// jumping - go faster
			this.currentVelocity = this.runSpeedRange[1] * app.scaling.scale;
		} else {
			this.currentVelocity = this.groundVelocity;
		}

		this.worldX -= this.currentVelocity * frameDelta;

		this.panel.background.x = Math.floor(this.worldX % Math.floor(1320 * app.scaling.scale));
		this.panel.background2.x = Math.floor((this.worldX % Math.floor(1320 * app.scaling.scale)) + Math.floor(1320 * app.scaling.scale));

		this.currentDistanceBetweenHurdles += this.currentVelocity * frameDelta;
	};

	p.updateWorldObjects = function(frameDelta)
	{
		var i = 0;
		// move spawned objects
		for (i = 0; i < this.activeHurdles.length; i++) {
			this.activeHurdles[i].x -= (this.currentVelocity / app.scaling.scale) * frameDelta;
		}
		for (i = 0; i < this.activeCookies.length; i++) {
			this.activeCookies[i].x -= (this.currentVelocity / app.scaling.scale) * frameDelta;

			// check for collisions
			var cookieCol = DL_Util.circleIntersect(this.panel.skin.CookieMonsterRun.x, this.panel.skin.CookieMonsterRun.y, this.panel.skin.CookieMonsterRun.nominalBounds.width / 3, this.activeCookies[i].x, this.activeCookies[i].y, this.activeCookies[i].nominalBounds.width / 2);
			if (cookieCol === true && this.activeCookies[i].visible === true) {
				this.collectCookie(i);
			}
		}

		// if spawned objects off screen, remove
		if (this.activeHurdles.length && this.activeHurdles[0].x < 0 - (this.activeHurdles[0].nominalBounds.width * 2)) {
			this.removeHurdle();
		}
		if (this.activeCookies.length && this.activeCookies[0].x < 0 - (this.activeCookies[0].nominalBounds.width / 2)) {
			this.removeCookie();
		}

		if (!this.showingFinishLine) {
			// spawn new items if necessary
			if (this.currentDistanceBetweenHurdles >= this.distanceBetweenHurdles * app.scaling.scale) {

				this.addHurdle();

			} else if (this.currentCookiesSpawnedBetweenHurdles < this.cookiesBetweenHurdles && this.currentDistanceBetweenHurdles >= (this.distanceBetweenHurdles * app.scaling.scale) * this.cookieSpawnPlacements[this.currentCookiesSpawnedBetweenHurdles]) {
				
				var cookieHeight = DL_Util.randPosNeg() > 0 ? "medium" : "low";
				this.addCookie(cookieHeight);

			}
		} else {
			this.panel.finishLine.x -= (this.currentVelocity / app.scaling.scale) * frameDelta;
		}
	};

	/**
	 * Sorting method for determining the order of children in the skin
	 * display list. i.e. which hurdles are in front of cookie
	 * @method  sortFunction
	 */
	p.sortFunction = function(obj1, obj2, options) {
		if (obj1.state && obj1.state === "down") { return -1; }
		if (obj2.state && obj2.state === "down") { return 1; }
		if (obj1.x > obj2.x) { return -1; }
		if (obj1.x < obj2.x) { return 1; }
		return 0;
	};

	/**
	 * Add a hurdle off screen right using the hurdle object pool
	 * @method  addHurdle
	 */
	p.addHurdle = function(xPos)
	{
		xPos = xPos || 1320;
		if (this.hurdlePool.length > 0) {
			this.activeHurdles.push(this.hurdlePool.shift());
		} else {
			this.activeHurdles.push(new lib.Hurdle());
		}
		var index = this.activeHurdles.length - 1;
		this.panel.skin.addChild(this.activeHurdles[index]);
		this.activeHurdles[index].gotoAndStop("Up");
		this.activeHurdles[index].x = xPos;
		this.activeHurdles[index].y = 430;

		this.addCookie("high", xPos);

		this.currentDistanceBetweenHurdles = 1320 - xPos;
		
		this.currentCookiesSpawnedBetweenHurdles = 0; // reset
	};

	/**
	 * Remove the leftmost hurdle from the active hurdles list
	 * and return it to the hurdle pool. Remove from stage as well.
	 * @method  removeHurdle
	 */
	p.removeHurdle = function()
	{
		this.hurdlePool.push(this.activeHurdles.shift());
		this.panel.skin.removeChild(this.hurdlePool[this.hurdlePool.length - 1]);
		if (this.hurdlePool[this.hurdlePool.length - 1].state === "down") {
			this.maxRunSpeed = Math.max(this.maxRunSpeed - this.runSpeedIncrement, this.runSpeedRange[0]);
		} else {
			this.maxRunSpeed = Math.min(this.maxRunSpeed + this.runSpeedIncrement, this.runSpeedRange[1]);
		}
	};

	/**
	 * Add a collectable cookie item to the stage using the 
	 * cookie object pool.
	 * @method  addCookie
	 */
	p.addCookie = function(height, xPos)
	{
		xPos = xPos || 1320;
		if (typeof height === 'undefined') {
			height = "high";
		}
		if (this.cookiePool.length > 0) {
			this.activeCookies.push(this.cookiePool.shift());
		} else {
			this.activeCookies.push(new lib.CookieCollectable());
		}
		var index = this.activeCookies.length - 1;
		this.panel.skin.addChild(this.activeCookies[index]);
		this.activeCookies[index].x = xPos + (this.activeCookies[0].nominalBounds.width / 2) + 50;

		this.activeCookies[index].y = app.config.userSettings.hurdleGameOptions.cookieHeights[height] || app.config.userSettings.hurdleGameOptions.cookieHeights.low; // default to low height if undefined
		
		this.activeCookies[index].Variations.gotoAndStop(DL_Util.getRandomInt(0, 5));
		this.activeCookies[index].visible = true;

		this.currentCookiesSpawnedBetweenHurdles += 1;
	};

	/**
	 * Remove leftmost cookie from the stage and return it to the cookie object pool.
	 * @method  removeCookie
	 */
	p.removeCookie = function()
	{
		this.cookiePool.push(this.activeCookies.shift());
		this.panel.skin.removeChild(this.cookiePool[this.cookiePool.length - 1]);
	};

	p.showFinishLine = function()
	{
		if (this.showingFinishLine) {
			return; // finish line has already spawned
		}
		this.showingFinishLine = true;
	};

	/**
	 * Hide the active cookie at the specified index and increment the score.
	 * @method  collectCookie
	 */
	p.collectCookie = function(index)
	{
		this.onResetInactivityTimeout();

		this.activeCookies[index].visible = false;
		this.cookiesCollectedCount += 1;
		this.panel.scoreText.text = this.cookiesCollectedCount.toString();
		app.sound.play("bellyes");
		this.onCharacterReact();
	};

	/**
	 * Logic to handle cookie monster's velocity when the jump event is triggered
	 * @method  onCookieMonsterJump
	 */
	p.onCookieMonsterJump = function()
	{
		this.onResetInactivityTimeout();

		if (this.panel.skin.CookieMonsterRun.y < this.cookieMonsterYPos) {
			return;
		} else {
			this.currentJumpVelocity = this.jumpForce;
			this.panel.skin.CookieMonsterRun.y += this.currentJumpVelocity;
			app.sound.play("hurdlebounce");
			this.panel.skin.CookieMonsterRun.gotoAndStop("jump");
			this.cookieMonsterState = "jumping";
			this.timesJumped += 1;
		}
	};

	p.onCharacterReact = function()
	{
		this.actionsSinceLastReaction += 1;
		if (this.actionsSinceLastReaction >= 3 && this.voPlayer.playing === false) {
			this.actionsSinceLastReaction = 0;
			var reactionNumber = DL_Util.getRandomInt(1, 20) + app.config.userSettings.numberVoOffsets.react;
			this.voPlayer.play("CG_" + reactionNumber);
		}
	};

	// Home button in corner
	p.onBack = function()
	{
		var eventLabel = this.completeScreenVisible === true ? "Hurdles_Complete Screen" : "Hurdles";
		GA_obj.trackEvent("button home", eventLabel);
		this.onStopGameplay();
		this.onResetInactivityTimeout();
		this.previousState();
	};

	p.onReplay = function()
	{
		this.onResetInactivityTimeout();
		app.config.globalState.gamePlayData.hurdleGame.consecutivePlays += 1;

		var rawNumber = app.config.globalState.gamePlayData.hurdleGame.consecutivePlays + 1, 
		paddedNumber = GA_obj.valueToPaddedString(rawNumber);

		GA_obj.trackEvent("replay", "Hurdles Replays_" + paddedNumber, rawNumber);

		this._nextState = "hurdleGame";
		this.nextState();
	};

	// Home button on end game screen
	p.onHome = function() {
		var eventLabel = this.completeScreenVisible === true ? "Hurdles_Complete Screen" : "Hurdles";
		GA_obj.trackEvent("button home", eventLabel);
		this.onResetInactivityTimeout();
		this.previousState();
		
	};

	/**
	 * Create and display the score screen
	 * @method  onGameEnd
	 */
	p.onGameEnd = function()
	{
		app.config.globalState.gamePlayData.hurdleGame.totalPlays += 1;
		app.config.globalState.lastCompletedGame = "hurdleGame";

		// padded numbers for all of these replays
		var paddedPlays = GA_obj.valueToPaddedString(app.config.globalState.gamePlayData.hurdleGame.totalPlays),
		paddedCookiesCollected = GA_obj.valueToPaddedString(this.cookiesCollectedCount),
		paddedHurdlesKnockedOver = GA_obj.valueToPaddedString(this.hurdlesKnockedOver),
		paddedTimesJumped = GA_obj.valueToPaddedString(this.timesJumped);

		GA_obj.trackEvent("Hurdles", "Plays_" + paddedPlays, app.config.globalState.gamePlayData.hurdleGame.totalPlays);
		GA_obj.trackEvent("Hurdles Info", "Jumps_" + paddedTimesJumped + " Missed Hurdles_" + paddedHurdlesKnockedOver + " Cookies_" + paddedCookiesCollected, this.timesJumped);

		this.onStopGameplay();

		app.sound.play("applause");

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}

		if (this.panel.finishLine.x < this.panel.skin.CookieMonsterRun.x) {
			// celebrate because we crossed the finish line
			this.panel.skin.CookieMonsterRun.gotoAndStop("victory pose");
		} else {
			// didn't cross the finish line in time
			this.panel.skin.CookieMonsterRun.gotoAndStop("hit_stand");
		}
		// set cookie's y position to be on the track
		this.panel.skin.CookieMonsterRun.y = this.cookieMonsterYPos;
		
		this.wrapUpTimeout = new Delay(this.onWrapUpComplete, 3000);
	};

	p.onWrapUpComplete = function()
	{
		this.panel.skin.CookieMonsterRun.stop();

		this.panel.createScorePanel(this.cookiesCollectedCount.toString());
		this.completeScreenVisible = true;

		// display score
		this.panel.replayButton.addEventListener("click", this.onReplay);
		this.panel.homeButton.addEventListener("click", this.onHome);

		var yTo = 10 * app.scaling.scale;
		this.panel.scoreScreen.y = 780;
		createjs.Tween.get(this.panel.scoreScreen).to({y: yTo}, 600, createjs.Ease.backOut);

		this.panel.backButton.alpha = 0;

		var completeScreenVo = [];

		if (this.cookiesCollectedCount > 0) {
			completeScreenVo.push("CG_31");
			completeScreenVo.push("CG_" + (app.config.userSettings.numberVoOffsets.final + this.cookiesCollectedCount));
		}

		// decide grovers VO lines based on score
		if (this.cookiesCollectedCount > 18) {
			completeScreenVo.push("CG_48");
		} else if (this.cookiesCollectedCount > 0) {
			var voString = DL_Util.randPosNeg() > 0 ? "CG_49" : "CG_50";
			completeScreenVo.push(voString);
		} else {
			completeScreenVo.push("CG_51");
		}

		this.voPlayer.play(completeScreenVo, this.fireCompleteScreenButtonPrompt);
	};

	p.fireGameplayPrompt = function()
	{
		var timeoutVo = [];
		if (app.config.globalState.consecutiveTimeouts === 1) {
			// timeout 1
			var voString = DL_Util.randPosNeg() > 0 ? "CG_39" : "CG_40";
			timeoutVo.push(voString);
			timeoutVo.push(app.config.globalState.inputPrompts.grover);
			timeoutVo.push("CG_53");
		} else {
			timeoutVo.push(app.config.globalState.inputPrompts.cookie);
			timeoutVo.push("CG_54");
		}
		this.voPlayer.play(timeoutVo, this.continueInactivityTimeout);
	};

	p.fireCompleteScreenButtonPrompt = function(timeout)
	{
		timeout = timeout || false;
		var completeScreenPrompts = [];

		if (timeout === true) {
			if (this.voPlayer.playing === true) {
				return;
			}
			completeScreenPrompts.push(app.config.globalState.inputPrompts.grover);
			completeScreenPrompts.push("CG_43");
			completeScreenPrompts.push(500);
			completeScreenPrompts.push(app.config.globalState.inputPrompts.grover);
			completeScreenPrompts.push("CG_44");
			this.voPlayer.play(completeScreenPrompts, this.continueInactivityTimeout);

			// tween highlights
			createjs.Tween.get(this.panel.replayButtonHighlight)
			.to({alpha: 1}, 200)
			.wait(2000)
			.to({alpha: 0}, 200);

			createjs.Tween.get(this.panel.homeButtonHighlight)
			.wait(3000)
			.to({alpha: 1}, 200)
			.wait(2000)
			.to({alpha: 0}, 200);
		} else {
			completeScreenPrompts.push("CG_52");
			completeScreenPrompts.push(500);
			completeScreenPrompts.push("CG_37");
			this.voPlayer.play(completeScreenPrompts, this.onResetInactivityTimeout);

			// tween highlights
			createjs.Tween.get(this.panel.replayButtonHighlight)
			.to({alpha: 1}, 200)
			.wait(2500)
			.to({alpha: 0}, 200);

			createjs.Tween.get(this.panel.homeButtonHighlight)
			.wait(3500)
			.to({alpha: 1}, 200)
			.wait(2000)
			.to({alpha: 0}, 200);
		}

	};

	/**
	 * Stop gameplay updates and kill timeouts
	 * @method  onStopGameplay
	 */
	p.onStopGameplay = function()
	{
		if (this.gameTimeout !== null) {
			this.gameTimeout.destroy();
		}

		if (this.finishLineTimeout !== null) {
			this.finishLineTimeout.destroy();
		}
		
		Ticker.removeEventListener('tick', this.onTick);
		window.removeEventListener("mousedown", this.onCookieMonsterJump);
		window.removeEventListener("touchstart", this.onCookieMonsterJump);
		app.keyboard.removeKeyDown("spacebar", this.onCookieMonsterJump);
	};

	p.onInactivityTimeout = function() {
		if (app.manager.currentState.stateId !== "hurdleGame") {
			return;
		}
		// play audio, etc.
		if (app.config.globalState.firstInactivityTimeoutTime === 0) {
			app.config.globalState.firstInactivityTimeoutTime = Date.now();
		}
		app.config.globalState.consecutiveTimeouts += 1;
		
		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		
		if (this.completeScreenVisible === true) {
			this.fireCompleteScreenButtonPrompt(true);
		} else {
			this.fireGameplayPrompt();
		}

		var timeInSeconds = Math.round((Date.now() - app.config.globalState.firstInactivityTimeoutTime) / 1000),
		paddedTimoutCount = GA_obj.valueToPaddedString(app.config.globalState.consecutiveTimeouts),
		eventLabel = this.completeScreenVisible === true ? "Hurdles_Complete Screen" : "Hurdles";
		GA_obj.trackEvent("TimeoutPlay", eventLabel + " Timeout_" + paddedTimoutCount, timeInSeconds);
	};

	p.continueInactivityTimeout = function()
	{
		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		this.inactivityTimeout = new Delay(this.onInactivityTimeout, app.config.userSettings.inactivityTimeoutDurations.default);
	};

	p.onResetInactivityTimeout = function() {
		// fired every time an interaction occurs
		if (app.config.globalState.firstInactivityTimeoutTime > 0) {
			var eventLabel = this.completeScreenVisible === true ? "Hurdles_Complete Screen" : "Hurdles";
			GA_obj.trackEvent("TOReEnage", eventLabel);
		}
		app.config.globalState.consecutiveTimeouts = 0;
		app.config.globalState.firstInactivityTimeoutTime = 0;

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		this.inactivityTimeout = new Delay(this.onInactivityTimeout, app.config.userSettings.inactivityTimeoutDurations.default);
	};

	/**
	 * When the state starts to exit, before transition
	 * @method  exitStart
	 */
	p.exitStart = function()
	{
		
	};

	p.exit = function()
	{
		// remove dynamically generated objects from stage
		for (var i = 0; i < this.activeHurdles.length; i++) {
			this.panel.skin.removeChild(this.activeHurdles[i]);
		}

		if (this.panel.replayButtonHighlight) {
			createjs.Tween.removeTweens(this.panel.replayButtonHighlight);
			createjs.Tween.removeTweens(this.panel.homeButtonHighlight);
		}

		this.cookiesCollectedCount = 0;
		this.hurdlesKnockedOver = 0;
		this.timesJumped = 0;
		this.worldX = 0;
		this.currentVelocity = 0;
		this.groundVelocity = 0;
		this.currentDistanceBetweenHurdles = 0;
		this.currentCookiesSpawnedBetweenHurdles = 0;
		this.currentJumpVelocity = 0;
		this.activeHurdles = [];
		this.hurdlePool = [];
		this.activeCookies = [];
		this.cookiePool = [];
		this.showingFinishLine = false;
		this.actionsSinceLastReaction = 0;
		this.gameplayStarted = false;

		this.nextHurdleToEngage = null;

		this.panel.backButton.removeEventListener("click", this.onBack);
		// remove temporary event listeners
		if (this.panel.replayButton) {
			this.panel.replayButton.removeEventListener("click", this.onReplay);
			this.panel.homeButton.removeEventListener("click", this.onHome);
		}

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		if (this.wrapUpTimeout !== null) {
			this.wrapUpTimeout.destroy();
		}
		if (this.gameTimeout !== null) {
			this.gameTimeout.destroy();
		}
		if (this.finishLineTimeout !== null) {
			this.finishLineTimeout.destroy();
		}
		app.config.globalState.firstInactivityTimeoutTime = 0;

		app.sound.stop("applause");
		app.sound.stop("music_gameplayloop.L");
		this.voPlayer.stop();
	};

	//Assign to namespace
	namespace('PrimalScreen').HurdleGameState = HurdleGameState;
}());
(function()
{
	//Import classes
	var BaseState = include('springroll.easeljs.BaseState'),
		RingGamePanel = include('PrimalScreen.RingGamePanel'),
		Delay = include('springroll.DelayedCall');

	/**
	 * The logic for the game state
	 * @class PrimalScreen.RingGameState
	 * @extends springroll.easeljs.BaseState
	 */
	var RingGameState = function(options)
	{
		BaseState.call(this, new RingGamePanel(), options);

		this.onBack = this.onBack.bind(this);
		this.onReplay = this.onReplay.bind(this);
		this.onHome = this.onHome.bind(this);
		this.onGameEnd = this.onGameEnd.bind(this);
		this.spinIntoPose = this.spinIntoPose.bind(this);
		this.onStrikePose = this.onStrikePose.bind(this);
		this.onReadyForNextPose = this.onReadyForNextPose.bind(this);
		this.onGestureStart = this.onGestureStart.bind(this);
		this.onTrackGesture = this.onTrackGesture.bind(this);
		this.onGestureEnd = this.onGestureEnd.bind(this);
		this.onStopGameplay = this.onStopGameplay.bind(this);
		this.introInstructions = this.introInstructions.bind(this);
		this.onGameplayStart = this.onGameplayStart.bind(this);
		this.onWrapUpComplete = this.onWrapUpComplete.bind(this);
		this.fireCompleteScreenButtonPrompt = this.fireCompleteScreenButtonPrompt.bind(this);
		this.fireGameplayPrompt = this.fireGameplayPrompt.bind(this);
		this.onCharacterReact = this.onCharacterReact.bind(this);

		this.onInactivityTimeout = this.onInactivityTimeout.bind(this);
		this.continueInactivityTimeout = this.continueInactivityTimeout.bind(this);
		this.onResetInactivityTimeout = this.onResetInactivityTimeout.bind(this);

		// tracking vars
		this.spinCount = 0;
		this.actionsSinceLastReaction = 0;
		this.gestureStart = null;
		this.lastGestureEvent = null;
		this.cookieMonsterState = "waiting"; // waiting, spinning, posing
		this.nextPose = "Standing";
		this.lastPose = "Standing";
		this.spinTimeout = null; // time to play spinning blur frames
		this.poseTimeout = null; // debounce - force cookie to hold a pose for this long before allowing a new interaction
		this.completeScreenVisible = false;

		this.gameTimeout = null;
		this.inactivityTimeout = null;
		this.wrapUpTimeout = null;
	};

	//Extend the base state
	var p = extend(RingGameState, BaseState);

	/**
	 * After assets are loaded and state is fully entered
	 * @method  enterDone
	 */
	p.enterDone = function()
	{
		//config vars
		this.swipeThreshold = app.config.userSettings.ringGameOptions.swipeThreshold;
		this.poseDuration = app.config.userSettings.ringGameOptions.poseDuration;
		this.spinDuration = app.config.userSettings.ringGameOptions.spinDuration;

		this.panel.backButton.addEventListener("click", this.onBack);
		this.panel.backButton.alpha = 1;
		this.completeScreenVisible = false;

		if (app.config.globalState.gamePlayData.ringGame.consecutivePlays === 0) {
			this.introInstructions();
		} else {
			this.onGameplayStart();
		}
		
	};

	p.introInstructions = function()
	{
		var introVo = [
			app.config.globalState.inputPrompts.grover,
			"CG_30"
		];
		this.voPlayer.play(introVo, this.onGameplayStart);
	};

	p.onGameplayStart = function()
	{
		window.addEventListener("mousedown", this.onGestureStart);
		window.addEventListener("touchstart", this.onGestureStart);
		window.addEventListener("mousemove", this.onTrackGesture);
		window.addEventListener("touchmove", this.onTrackGesture);
		window.addEventListener("mouseup", this.onGestureEnd);
		window.addEventListener("touchend", this.onGestureEnd);

		this.gameTimeout = new Delay(this.onGameEnd, app.config.userSettings.gameDurations.rings);

		app.sound.play("music_gameplayloop.L");

		// start the inactivity timeout for the first time
		app.config.globalState.firstInactivityTimeoutTime = 0;
		this.onResetInactivityTimeout();
	};

	p.onBack = function()
	{
		var eventLabel = this.completeScreenVisible === true ? "Rings_Complete Screen" : "Rings";
		GA_obj.trackEvent("button home", eventLabel);
		this.onResetInactivityTimeout();
		this.onStopGameplay();

		this.previousState();
	};

	p.onReplay = function()
	{
		this.onResetInactivityTimeout();

		app.config.globalState.gamePlayData.ringGame.consecutivePlays += 1;

		var rawNumber = app.config.globalState.gamePlayData.ringGame.consecutivePlays + 1, 
		paddedNumber = GA_obj.valueToPaddedString(rawNumber);

		GA_obj.trackEvent("replay", "Rings Replays_" + paddedNumber, rawNumber);

		this._nextState = "ringGame";
		this.nextState();
	};

	p.onHome = function() {
		var eventLabel = this.completeScreenVisible === true ? "Rings_Complete Screen" : "Rings";
		GA_obj.trackEvent("button home", eventLabel);
		this.onResetInactivityTimeout();
		this.previousState();
	};

	p.onGestureStart = function(event)
	{
		// console.log(event);
		this.onResetInactivityTimeout();
		if (event.changedTouches) {
			this.gestureStart = {x: event.changedTouches[0].pageX, y: event.changedTouches[0].pageY};
		} else if (event.pageX) {
			this.gestureStart = {x: event.pageX, y: event.pageY};
		} else {
			this.gestureStart = {x: 0, y: 0};
		}

		if (this.cookieMonsterState !== "waiting") {
			return;
		}
		this.nextPose = "NoPose";
		this.spinIntoPose();

	};

	p.onTrackGesture = function(event)
	{
		this.lastGestureEvent = event;
	};

	p.onGestureEnd = function(event)
	{
		this.onResetInactivityTimeout();

		if (typeof event === "undefined") {
			event = this.lastGestureEvent;
		}

		if (app.hasTouch === true) {
			// do gesture based performance
			var endPos = {x: 0, y: 0};

			if (event.changedTouches) {
				endPos = {x: event.changedTouches[0].pageX, y: event.changedTouches[0].pageY};
			} else if (event.pageX) {
				endPos = {x: event.pageX, y: event.pageY};
			} else {
				endPos = {x: 0, y: 0};
			}

			var deltaX = Math.abs(endPos.x - this.gestureStart.x);
			var deltaY = Math.abs(endPos.y - this.gestureStart.y);

			if (deltaX > this.swipeThreshold && deltaX > deltaY) {
				// horizontal swipe
				this.nextPose = DL_Util.randPosNeg() > 0 ? "Pose1_up" : "Pose2_up";

			} else if (deltaY > this.swipeThreshold && deltaY > deltaX) {
				// vertical swipe
				this.nextPose = DL_Util.randPosNeg() > 0 ? "Pose1_down" : "Pose2_down";

			} else {
				// tap
				this.nextPose = DL_Util.randPosNeg() > 0 ? "Pose1_tap" : "Pose2_tap";
			}
		} else {
			// make one click randomize between all poses
			var randomPose = this.lastPose;
			while (randomPose == this.lastPose) {
				var allPoses = [
					"Pose1_up",
					"Pose2_up",
					"Pose1_down",
					"Pose2_down",
					"Pose1_tap",
					"Pose2_tap"
				];
				randomPose = allPoses[DL_Util.getRandomInt(0, 5)];
			}
			this.nextPose = randomPose;
		}
		
	};

	p.spinIntoPose = function()
	{
		// if (this.cookieMonsterState === "posing") {
		// 	return;
		// }

		this.cookieMonsterState = "spinning";

		this.panel.skin.gotoAndPlay("SpinHorizontal");

		// play random sound
		var spinSound = DL_Util.randPosNeg() > 0 ? "ringsdown" : "ringsup";
		app.sound.play(spinSound);

		if (this.spinTimeout !== null) {
			this.spinTimeout.destroy();
		}

		this.spinTimeout = new Delay(this.onStrikePose, this.spinDuration);
	};

	p.onStrikePose = function()
	{
		if (this.nextPose === "NoPose") {
			this.onGestureEnd();
		}
		// we did a trick, get a point
		this.spinCount += 1;
		this.panel.scoreText.text = this.spinCount.toString();
		app.sound.play("bellyes");

		this.panel.skin.gotoAndPlay(this.nextPose);
		this.cookieMonsterState = "posing";
		this.nextPose = this.nextPose;
		this.lastPose = this.nextPose;

		if (this.poseTimeout !== null) {
			this.poseTimeout.destroy();
		}
		this.poseTimeout = new Delay(this.onReadyForNextPose, this.poseDuration);
		this.onCharacterReact();
	};

	p.onReadyForNextPose = function()
	{
		if (this.poseTimeout !== null) {
			this.poseTimeout.destroy();
		}
		this.cookieMonsterState = "waiting";
	};

	p.onGameEnd = function()
	{
		app.config.globalState.gamePlayData.ringGame.totalPlays += 1;
		app.config.globalState.lastCompletedGame = "ringGame";

		var paddedPlays = GA_obj.valueToPaddedString(app.config.globalState.gamePlayData.ringGame.totalPlays);
		var paddedScore = GA_obj.valueToPaddedString(this.spinCount);

		GA_obj.trackEvent("Rings", "Plays_" + paddedPlays, app.config.globalState.gamePlayData.ringGame.totalPlays);
		GA_obj.trackEvent("Rings Info", "Moves_" + paddedScore, this.spinCount);

		this.onStopGameplay();

		app.sound.play("applause");

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}

		this.panel.skin.gotoAndStop("victory pose");
		this.panel.skin.CookieMonsterVictory.framerate = 24;
		this.wrapUpTimeout = new Delay(this.onWrapUpComplete, 3000);
	};

	p.onWrapUpComplete = function()
	{
		// play after wrap up animation has completed
		this.panel.createScorePanel(this.spinCount.toString());
		this.completeScreenVisible = true;

		// display score
		this.panel.replayButton.addEventListener("click", this.onReplay);
		this.panel.homeButton.addEventListener("click", this.onHome);

		var yTo = 10 * app.scaling.scale;
		this.panel.scoreScreen.y = 780;
		createjs.Tween.get(this.panel.scoreScreen).to({y: yTo}, 600, createjs.Ease.backOut);

		this.panel.backButton.alpha = 0;

		var completeScreenVo = [];

		if (this.spinCount > 0) {
			completeScreenVo.push("CG_31");
			completeScreenVo.push("CG_" + (app.config.userSettings.numberVoOffsets.final + this.spinCount));
		}

		// decide grovers VO lines based on score
		if (this.spinCount > 18) {
			completeScreenVo.push("CG_32");
		} else if (this.spinCount > 0) {
			var voString = DL_Util.randPosNeg() > 0 ? "CG_33" : "CG_34";
			completeScreenVo.push(voString);
		} else {
			completeScreenVo.push("CG_35");
		}

		this.panel.skin.CookieMonsterVictory.stop();
		this.voPlayer.play(completeScreenVo, this.fireCompleteScreenButtonPrompt);
	};

	p.onCharacterReact = function()
	{
		var reactVO = [];
		reactVO.push("CG_" + (app.config.userSettings.numberVoOffsets.final + this.spinCount));

		this.actionsSinceLastReaction += 1;
		if (this.actionsSinceLastReaction >= 3 && this.voPlayer.playing === false) {
			this.actionsSinceLastReaction = 0;
			var reactionNumber = DL_Util.getRandomInt(1, 20) + app.config.userSettings.numberVoOffsets.react;
			reactVO.push("CG_" + reactionNumber);
		}

		this.voPlayer.play(reactVO);
	};

	p.fireGameplayPrompt = function()
	{
		var timeoutVo = [];
		if (app.config.globalState.consecutiveTimeouts === 1) {
			// timeout 1
			var voString = DL_Util.randPosNeg() > 0 ? "CG_39" : "CG_40";
			timeoutVo.push(voString);
			timeoutVo.push(app.config.globalState.inputPrompts.grover);
			timeoutVo.push("CG_41");
		} else {
			timeoutVo.push(app.config.globalState.inputPrompts.cookie);
			timeoutVo.push("CG_42");
		}
		this.voPlayer.play(timeoutVo, this.continueInactivityTimeout);
	};

	p.fireCompleteScreenButtonPrompt = function(timeout)
	{
		timeout = timeout || false;
		var completeScreenPrompts = [];

		if (timeout === true) {
			if (this.voPlayer.playing === true) {
				return;
			}
			completeScreenPrompts.push(app.config.globalState.inputPrompts.grover);
			completeScreenPrompts.push("CG_43");
			completeScreenPrompts.push(app.config.globalState.inputPrompts.grover);
			completeScreenPrompts.push("CG_44");
			this.voPlayer.play(completeScreenPrompts, this.continueInactivityTimeout);

			// tween highlights
			createjs.Tween.get(this.panel.replayButtonHighlight)
			.to({alpha: 1}, 200)
			.wait(2000)
			.to({alpha: 0}, 200);

			createjs.Tween.get(this.panel.homeButtonHighlight)
			.wait(3000)
			.to({alpha: 1}, 200)
			.wait(2000)
			.to({alpha: 0}, 200);
		} else {
			completeScreenPrompts.push("CG_36");
			completeScreenPrompts.push("CG_37");
			this.voPlayer.play(completeScreenPrompts, this.onResetInactivityTimeout);

			// tween highlights
			createjs.Tween.get(this.panel.replayButtonHighlight)
			.to({alpha: 1}, 200)
			.wait(2500)
			.to({alpha: 0}, 200);

			createjs.Tween.get(this.panel.homeButtonHighlight)
			.wait(3500)
			.to({alpha: 1}, 200)
			.wait(2000)
			.to({alpha: 0}, 200);
		}

	};

	p.onStopGameplay = function()
	{
		if (this.gameTimeout !== null) {
			this.gameTimeout.destroy();
		}

		if (this.spinTimeout !== null) {
			this.spinTimeout.destroy();
		}

		if (this.poseTimeout !== null) {
			this.poseTimeout.destroy();
		}

		window.removeEventListener("mousedown", this.onGestureStart);
		window.removeEventListener("touchstart", this.onGestureStart);
		window.removeEventListener("mousemove", this.onTrackGesture);
		window.removeEventListener("touchmove", this.onTrackGesture);
		window.removeEventListener("mouseup", this.onGestureEnd);
		window.removeEventListener("touchend", this.onGestureEnd);
	};

	p.onInactivityTimeout = function() {
		if (app.manager.currentState.stateId !== "ringGame") {
			return;
		}
		// play audio, etc.
		if (app.config.globalState.firstInactivityTimeoutTime === 0) {
			app.config.globalState.firstInactivityTimeoutTime = Date.now();
		}
		app.config.globalState.consecutiveTimeouts += 1;
		
		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}

		if (this.completeScreenVisible === true) {
			this.fireCompleteScreenButtonPrompt(true);
		} else {
			this.fireGameplayPrompt();
		}

		var timeInSeconds = Math.round((Date.now() - app.config.globalState.firstInactivityTimeoutTime) / 1000),
		paddedTimoutCount = GA_obj.valueToPaddedString(app.config.globalState.consecutiveTimeouts),
		eventLabel = this.completeScreenVisible === true ? "Rings_Complete Screen" : "Rings";
		GA_obj.trackEvent("TimeoutPlay", eventLabel + " Timeout_" + paddedTimoutCount, timeInSeconds);
	};

	p.continueInactivityTimeout = function()
	{
		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		this.inactivityTimeout = new Delay(this.onInactivityTimeout, app.config.userSettings.inactivityTimeoutDurations.default);
	};

	p.onResetInactivityTimeout = function() {
		// fired every time an interaction occurs
		if (app.config.globalState.firstInactivityTimeoutTime > 0) {
			var eventLabel = this.completeScreenVisible === true ? "Rings_Complete Screen" : "Rings";
			GA_obj.trackEvent("TOReEnage", eventLabel);
		}
		app.config.globalState.consecutiveTimeouts = 0;
		app.config.globalState.firstInactivityTimeoutTime = 0;

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		this.inactivityTimeout = new Delay(this.onInactivityTimeout, app.config.userSettings.inactivityTimeoutDurations.default);
	};

	/**
	 * When the state starts to exit, before transition
	 * @method  exitStart
	 */
	p.exitStart = function()
	{
		
	};

	p.exit = function()
	{
		this.spinCount = 0;
		this.actionsSinceLastReaction = 0;
		this.gestureStart = null;
		this.lastGestureEvent = null;
		this.cookieMonsterState = "waiting"; // waiting, spinning, posing
		this.nextPose = "Standing";
		this.lastPose = "Standing";
		this.poseTimeout = null;

		// remove temporary event listeners
		this.panel.backButton.removeEventListener("click", this.onBack);
		if (this.panel.replayButton) {
			this.panel.replayButton.removeEventListener("click", this.onReplay);
			this.panel.homeButton.removeEventListener("click", this.onHome);
		}

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}

		if (this.wrapUpTimeout !== null) {
			this.wrapUpTimeout.destroy();
		}
		app.config.globalState.firstInactivityTimeoutTime = 0;

		if (this.panel.replayButtonHighlight) {
			createjs.Tween.removeTweens(this.panel.replayButtonHighlight);
			createjs.Tween.removeTweens(this.panel.homeButtonHighlight);
		}

		app.sound.stop("applause");
		app.sound.stop("music_gameplayloop.L");
		this.voPlayer.stop();
	};

	//Assign to namespace
	namespace('PrimalScreen').RingGameState = RingGameState;
}());
(function()
{
	//Import classes
	var BaseState = include('springroll.easeljs.BaseState'),
		Delay = include('springroll.DelayedCall'),
		TitlePanel = include('PrimalScreen.TitlePanel');

	/**
	 * The logic for the title state
	 * @class PrimalScreen.TitleState
	 * @extends springroll.easeljs.BaseState
	 */
	var TitleState = function(options)
	{
		BaseState.call(this, new TitlePanel(), options);

		this.onPlay = this.onPlay.bind(this);
		this.onInactivityTimeout = this.onInactivityTimeout.bind(this);
		this.onResetInactivityTimeout = this.onResetInactivityTimeout.bind(this);

		this.inactivityTimeout = null;
	};

	// Extend the base class
	var p = extend(TitleState, BaseState);

	/**
	 * When the transition is done playing and we're fully in
	 */
	p.enterDone = function()
	{
		app.keyboard.restrictScrollingKeys();
		app.transition.mouseEnabled = false; // prevent rapid click issues

		// Click either the background or the button
		this.panel.playButton.addEventListener("buttonPress", this.onPlay);
		this.panel.background.addEventListener("click", this.onPlay);

		// randomize or otherwise set up global vars
		DL_Util.shuffle(app.config.globalState.correctEmotionOrder);

		// start the inactivity timeout for the first time
		app.config.globalState.firstInactivityTimeoutTime = 0;
		this.onResetInactivityTimeout();

		this.voPlayer.play("CG_1");
	};

	/**
	 * Handler when the play button is clicked
	 * @method  onPlay
	 * @private
	 */
	p.onPlay = function(event)
	{
		this.onResetInactivityTimeout();

		if (event.target === this.panel.playButton) {
			GA_obj.trackEvent("start", "StartButton");
		} else {
			GA_obj.trackEvent("start", "NotStartButton");
		}
		
		this.nextState();
	};

	p.onInactivityTimeout = function() {
		// play audio, etc.
		this.voPlayer.play("CG_2");

		if (app.config.globalState.firstInactivityTimeoutTime === 0) {
			app.config.globalState.firstInactivityTimeoutTime = Date.now();
		}
		app.config.globalState.consecutiveTimeouts += 1;

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		this.inactivityTimeout = new Delay(this.onInactivityTimeout, app.config.userSettings.inactivityTimeoutDurations.default);

		var timeInSeconds = Math.round((Date.now() - app.config.globalState.firstInactivityTimeoutTime) / 1000),
		paddedTimoutCount = GA_obj.valueToPaddedString(app.config.globalState.consecutiveTimeouts);
		GA_obj.trackEvent("TimeoutPlay", "Load Screen Timeout_" + paddedTimoutCount, timeInSeconds);
	};

	p.onResetInactivityTimeout = function() {
		// fired every time an interaction occurs
		if (app.config.globalState.firstInactivityTimeoutTime > 0) {
			var timeInSeconds = Math.round((Date.now() - app.config.globalState.firstInactivityTimeoutTime) / 1000),
			paddedTimoutCount = GA_obj.valueToPaddedString(app.config.globalState.consecutiveTimeouts);
			GA_obj.trackEvent("TOReEnage", "Load Screen");
		}
		app.config.globalState.consecutiveTimeouts = 0;
		app.config.globalState.firstInactivityTimeoutTime = 0;

		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		this.inactivityTimeout = new Delay(this.onInactivityTimeout, app.config.userSettings.inactivityTimeoutDurations.default);
	};

	/**
	 * When the state fully exits
	 * @method  exit
	 */
	p.exit = function()
	{
		if (this.inactivityTimeout !== null) {
			this.inactivityTimeout.destroy();
		}
		app.config.globalState.firstInactivityTimeoutTime = 0;
		this.voPlayer.stop();

		// Release event listeners
		this.panel.background.cursor = null;
		this.panel.background.removeEventListener("click", this.onPlay);
		this.panel.playButton.removeEventListener("click", this.onPlay);
	};

	//Assign to namespace
	namespace("PrimalScreen").TitleState = TitleState;
}());

(function()
{
	// Library depencencies
	var TitleState = include('PrimalScreen.TitleState'),
		GameSelectState = include('PrimalScreen.GameSelectState'),
		RingGameState = include('PrimalScreen.RingGameState'),
		HurdleGameState = include('PrimalScreen.HurdleGameState'),
		ArcheryGameState = include('PrimalScreen.ArcheryGameState'),
		FinaleState = include('PrimalScreen.FinaleState'),
		EmotionIdentificationState = include('PrimalScreen.EmotionIdentificationState'),
		BreathingExerciseState = include('PrimalScreen.BreathingExerciseState'),
		Application = include('springroll.Application'),
		Transition = include('lib.Transition'),
		Container = include('createjs.Container'),
		Bitmap = include('createjs.Bitmap'),
		Display = include('springroll.easeljs.EaselJSDisplay');

	// var transition = new Transition();
	// transition.framerate = 30;

	var CookieGames = function()
	{
		Application.call(this, {
			fps: 60,
			minLogLevel: 4,
			name: 'Sesame Summer Games',
			state: 'title',
			canvasId: 'stage',
			configPath: 'assets/config/config.json',
			manifestsPath: 'assets/config/manifests.json',
			captionsPath: 'assets/config/captions.json',
			transition: new Transition(),
			transitionSounds: {
				"in": "",
				"out": ""
			},
			display: Display,
			displayOptions:	{
				clearView: true,
				mouseOverRate: 20
			},
			// autoPause: false
		});

		this.onResize = this.onResize.bind(this);
		
		//set up listeners for initialization
		this.once("configLoaded", onConfigLoaded.bind(this));
		this.once("init", onInit.bind(this));

		this.onWindowUnload = this.onWindowUnload.bind(this);
		window.addEventListener("unload", this.onWindowUnload);
	};

	var p = extend(CookieGames, Application);

	p.onWindowUnload = function()
	{
		window.removeEventListener("unload", this.onWindowUnload);
		
		this.destroy();//destroy the game
	};

	var onConfigLoaded = function(config, assets)
	{
		//on mobile, resize to the top window to get the correct size due to browser UI.
		if(this.hasTouch && !this.container.connected) {
			this._resizeElement = window.top;
		}
		
		//force a resize now to ensure that the game doesn't think it is 1024x660
		this.triggerResize();

		// add cursor assets for desktop
		if(!this.hasTouch) {
			assets.push(this.config.assets.cursor[0]); // default cursor
			assets.push(this.config.assets.cursor[1]); // rollover cursor
		}

		// change input prompt lines based on touch
		if (this.hasTouch) {
			app.config.globalState.inputPrompts.cookie = "CG_82";
			app.config.globalState.inputPrompts.grover = "CG_84";
		}

		assets.push({
			"id": "QuitButton",
			"src": "assets/images/closebutton.png"
		});

		app.config.globalState.timeOfGameStart = Date.now();
	};

	// App has been initialized
	var onInit = function()
	{

		this.cursor = null;
		var display = this.display;
		var canvas = display.canvas;

		//initialize states
		var transition = this.options.transition = new lib.Transition();
		transition.framerate = 24;
		//set a strict size that the transition represents
		transition.width = 1320;
		transition.height = 780;
		//remove the nominal bounds, as we don't want to use it
		transition.nominalBounds = null;

		//Create the calling from the configuration
		//This will only scale items on the root of the stage
		this.scaling.addItem(transition,
			{
				x:(1024-1320)/2,
				y:(660-780)/2,
				titleSafe:true,
				align:"top-left"
			});
		this.scaling.enabled = true;
		
		this.on("resize", this.onResize, -1);



		var assets = this.config.assets;
		var scaling = this.config.scaling;
		var fla = this.manifests;



		// Set the states to use
		this.states = {
			title: new TitleState({
				next: 'gameSelect',
				preload: assets.title,
				scaling: scaling.title
			}),
			gameSelect: new GameSelectState({
				next: 'title', 
				previous: 'title',
				preload: assets.gameSelect,
				scaling: scaling.gameSelect
			}),
			ringGame: new RingGameState({
				next: 'gameSelect', 
				previous: 'gameSelect',
				preload: assets.ringGame,
				scaling: scaling.ringGame
			}),
			hurdleGame: new HurdleGameState({
				next: 'gameSelect', 
				previous: 'gameSelect',
				preload: assets.hurdleGame,
				scaling: scaling.hurdleGame
			}),
			archeryGame: new ArcheryGameState({
				next: 'gameSelect', 
				previous: 'gameSelect',
				preload: assets.archeryGame,
				scaling: scaling.archeryGame
			}),
			finaleScene: new FinaleState({
				next: 'gameSelect', 
				previous: 'gameSelect',
				preload: assets.finale,
				scaling: scaling.finale
			}),
			emotionIdentification: new EmotionIdentificationState({
				next: 'breathingExercise', 
				previous: 'gameSelect',
				preload: assets.emotionIdentification,
				scaling: scaling.emotionIdentification
			}),
			breathingExercise: new BreathingExerciseState({
				next: 'gameSelect', 
				previous: 'gameSelect',
				preload: assets.breathingExercise,
				scaling: scaling.breathingExercise
			})
		};

		var stage = display.stage;

		if (global_doNotDisplayClose === false) {
			this.quitButton = new Bitmap(app.assetManager.cache.read("QuitButton"));
			this.onQuitTap = this.onQuitTap.bind(this);
			this.quitButton.addEventListener("click", this.onQuitTap);
			this.quitButton.regX = 28;
			this.quitButton.regY = 28;
			// this.quitButton.x = 500;

			this.scaling.addItem(this.quitButton,
			{
				x:980,
				y:80,
				// titleSafe:true,
				align:"top-right"
			});

			stage.addChild(this.quitButton);
		}

		// add and bind cursor
		if(!this.hasTouch)
		{
			stage.addEventListener("mouseleave", this.stageOut.bind(this));
			stage.addEventListener("mouseenter", this.stageIn.bind(this));
			stage.addEventListener("stagemousemove", this.onMouseMove.bind(this));
			stage.addEventListener("changecursor", this.onCursorChange.bind(this));
			//hide default cursor to show sesame star cursor
			this.display.canvas.style.cursor = "none";
			//Create the cursor
			this.cursor = new Container();

			this.cursorDefault = new Bitmap(app.assetManager.cache.read("CursorDefault"));
			this.cursor.addChild(this.cursorDefault);
			this.cursorPointer = new Bitmap(app.assetManager.cache.read("CursorOver"));
			this.cursor.addChild(this.cursorPointer);
			this.cursorPointer.visible = false;
			this.cursorDefault.regX = 18;
			this.cursorDefault.regY = 18;
			this.cursorPointer.regX = 18;
			this.cursorPointer.regY = 18;
			stage.addChild(this.cursor);
			this.currentDragged = this.currentDraggedOffset = null;
		}

		

		// set the createjs ticker fps, because the app fps option does not use it for some reason
		createjs.Ticker.framerate = 60;
		// set tick speed
		createjs.Ticker.timingMode = createjs.Ticker.RAF; // makes hurdles scroll slow, no fix for skip frames

		this.display.visible = true;

		GA_obj.trackEvent("load", "Complete");
	};

	p.onResize = function(w, h)
	{
		//tells the container element what size to be for proper placement
		//due to absolute/relative positioning stuff
		var container = document.getElementById("container");
		//container.style.width = w + "px";
		//container.style.height = h + "px";
		if(container.scrollIntoViewIfNeeded)
			container.scrollIntoViewIfNeeded(true);
		
		//keep track of the last window size in case of UI changes
		//this.lastWindowSize = window.top.innerHeight;
	};

	// cursor handling
	p.stageOut = function()
	{
		if(this.cursor) {
			this.cursor.visible = false;
		}
	};

	p.stageIn = function()
	{
		if(this.cursor) {
			this.cursor.visible = true;
		}
	};
	
	p.onCursorChange = function(ev)
	{
		this.cursorPointer.visible = ev.cursor == "pointer";
		this.cursorDefault.visible = ev.cursor != "pointer";
	};
	
	p.onMouseMove = function(ev)
	{
		this._lastStageX = ev.stageX;
		this._lastStageY = ev.stageY;
		
		if(this.currentDragged) {
			return;
		}
		
		this.cursor.x = ev.stageX;
		this.cursor.y = ev.stageY;
	};

	p.onQuitTap = function()
	{
		GA_obj.trackEvent("button exit", GA_obj.gameID);
		window.close();
	};

	p.destroy = function()
	{
		var timeInSeconds = Math.round((Date.now() - app.config.globalState.timeOfGameStart) / 1000);
		var lastActivity = app.config.globalState.mostRecentScreen;
		if (lastActivity === "Rings" || lastActivity === "Hurdles" || lastActivity === "Archery") {
			if (app.manager.currentState.completeScreenVisible === true) {
				lastActivity = lastActivity + "_Complete Screen";
			}
		}
		// app.manager.currentState.completeScreenVisible
		// mostRecentScreen
		GA_obj.trackEvent("Quit", lastActivity); // get screen we quit from
		GA_obj.trackEvent("QuitInfo", "GameDuration", timeInSeconds);
		
		this.onWindowUnload = null;
		if(this.quitButton)
			this.quitButton.removeEventListener("click", this.onQuitTap);
		this.quitButton = null;
		
		Application.prototype.destroy.call(this);
	};

	// Give window access to the app
	window.app = new CookieGames();

}());

//# sourceMappingURL=main.js.map